@@ -51,6 +51,7 @@
 #include <locale.h>
 
 #include <ws_exit_codes.h>
+#include <wsutil/clopts_common.h>
 #include <wsutil/ws_getopt.h>
 
 #include <glib.h>
@@ -68,7 +69,6 @@
 #include <wsutil/plugins.h>
 #endif
 
-#include <wsutil/report_message.h>
 #include <wsutil/str_util.h>
 #include <wsutil/to_str.h>
 #include <wsutil/file_util.h>
@@ -175,7 +175,7 @@ typedef enum {
 } order_t;
 
 typedef struct _pkt_cmt {
-  int recno;
+  uint32_t recno;
   char *cmt;
   struct _pkt_cmt *next;
 } pkt_cmt;
@@ -627,45 +627,45 @@ print_stats(const char *filename, capture_info *cf_info)
                     show_option_string("Capture comment:     ", str);
                 }
             }
-
-            if (pkt_comments && cf_info->pkt_cmts != NULL) {
-              for (p = cf_info->pkt_cmts; p != NULL; prev = p, p = p->next, g_free(prev)) {
-                if (machine_readable){
-                  printf("Packet %d Comment:    %s\n", p->recno, g_strescape(p->cmt, NULL));
-                } else {
-                  printf("Packet %d Comment:    %s\n", p->recno, p->cmt);
-                }
-                g_free(p->cmt);
-              }
-            }
-
-            if (cap_file_idb && cf_info->num_interfaces != 0) {
-                unsigned int i;
-                ws_assert(cf_info->num_interfaces == cf_info->idb_info_strings->len);
-                printf     ("Number of interfaces in file: %u\n", cf_info->num_interfaces);
-                for (i = 0; i < cf_info->idb_info_strings->len; i++) {
-                    char *s = g_array_index(cf_info->idb_info_strings, char*, i);
-                    uint32_t packet_count = 0;
-                    if (i < cf_info->interface_packet_counts->len)
-                        packet_count = g_array_index(cf_info->interface_packet_counts, uint32_t, i);
-                    printf   ("Interface #%u info:\n", i);
-                    printf   ("%s", s);
-                    printf   ("                     Number of packets = %u\n", packet_count);
-                }
-            }
         }
+    }
 
-        if (cap_file_nrb) {
-            if (num_ipv4_addresses != 0)
-                printf   ("Number of resolved IPv4 addresses in file: %u\n", num_ipv4_addresses);
-            if (num_ipv6_addresses != 0)
-                printf   ("Number of resolved IPv6 addresses in file: %u\n", num_ipv6_addresses);
+    if (pkt_comments && cf_info->pkt_cmts != NULL) {
+      for (p = cf_info->pkt_cmts; p != NULL; prev = p, p = p->next, g_free(prev)) {
+        if (machine_readable){
+          printf("Packet %u Comment:    %s\n", p->recno, g_strescape(p->cmt, NULL));
+        } else {
+          printf("Packet %u Comment:    %s\n", p->recno, p->cmt);
         }
-        if (cap_file_dsb) {
-            if (num_decryption_secrets != 0)
-                printf   ("Number of decryption secrets in file: %u\n", num_decryption_secrets);
+        g_free(p->cmt);
+      }
+    }
+
+    if (cap_file_idb && cf_info->num_interfaces != 0) {
+        unsigned int i;
+        ws_assert(cf_info->num_interfaces == cf_info->idb_info_strings->len);
+        printf     ("Number of interfaces in file: %u\n", cf_info->num_interfaces);
+        for (i = 0; i < cf_info->idb_info_strings->len; i++) {
+            char *s = g_array_index(cf_info->idb_info_strings, char*, i);
+            uint32_t packet_count = 0;
+            if (i < cf_info->interface_packet_counts->len)
+                packet_count = g_array_index(cf_info->interface_packet_counts, uint32_t, i);
+            printf   ("Interface #%u info:\n", i);
+            printf   ("%s", s);
+            printf   ("                     Number of packets = %u\n", packet_count);
         }
     }
+
+    if (cap_file_nrb) {
+        if (num_ipv4_addresses != 0)
+            printf   ("Number of resolved IPv4 addresses in file: %u\n", num_ipv4_addresses);
+        if (num_ipv6_addresses != 0)
+            printf   ("Number of resolved IPv6 addresses in file: %u\n", num_ipv6_addresses);
+    }
+    if (cap_file_dsb) {
+        if (num_decryption_secrets != 0)
+            printf   ("Number of decryption secrets in file: %u\n", num_decryption_secrets);
+    }
 }
 
 static void
@@ -680,12 +680,16 @@ putquote(void)
     if (quote_char) putchar(quote_char);
 }
 
-static void
-print_stats_table_header_label(const char *label)
+static void G_GNUC_PRINTF(1, 2)
+print_stats_table_header_label(const char *fmt, ...)
 {
+    va_list ap;
+
     putsep();
     putquote();
-    printf("%s", label);
+    va_start(ap, fmt);
+    vprintf(fmt, ap);
+    va_end(ap);
     putquote();
 }
 
@@ -729,17 +733,9 @@ print_stats_table_header(capture_info *cf_info)
     if (cap_comment)        print_stats_table_header_label("Capture comment");
 
     if (pkt_comments && cf_info->pkt_cmts != NULL) {
-        char    *buf;
-        size_t   buf_len;
-        /* Packet 2^64 Comment" + NULL */
-        buf_len = strlen("Packet 18446744073709551616 Comment") + 1;
-        buf = (char *)g_malloc0(buf_len);
-
         for (p = cf_info->pkt_cmts; p != NULL; p = p->next) {
-            snprintf(buf, buf_len, "Packet %d Comment", p->recno);
-            print_stats_table_header_label(buf);
+            print_stats_table_header_label("Packet %u Comment", p->recno);
         }
-        g_free(buf);
     }
 
     printf("\n");
@@ -1031,7 +1027,7 @@ count_ipv4_address(const unsigned int addr _U_, const char *name _U_, const bool
 }
 
 static void
-count_ipv6_address(const void *addrp _U_, const char *name _U_, const bool static_entry _U_)
+count_ipv6_address(const ws_in6_addr *addrp _U_, const char *name _U_, const bool static_entry _U_)
 {
     num_ipv6_addresses++;
 }
@@ -1092,7 +1088,6 @@ process_cap_file(const char *filename, bool need_separator)
     uint32_t              snaplen_min_inferred = 0xffffffff;
     uint32_t              snaplen_max_inferred =          0;
     wtap_rec              rec;
-    Buffer                buf;
     capture_info          cf_info;
     bool                  have_times = true;
     nstime_t              earliest_packet_time;
@@ -1159,9 +1154,8 @@ process_cap_file(const char *filename, bool need_separator)
     wtap_set_cb_new_secrets(cf_info.wth, count_decryption_secret);
 
     /* Tally up data that we need to parse through the file to find */
-    wtap_rec_init(&rec);
-    ws_buffer_init(&buf, 1514);
-    while (wtap_read(cf_info.wth, &rec, &buf, &err, &err_info, &data_offset))  {
+    wtap_rec_init(&rec, 1514);
+    while (wtap_read(cf_info.wth, &rec, &err, &err_info, &data_offset))  {
         if (rec.presence_flags & WTAP_HAS_TS) {
             prev_time = cur_time;
             cur_time = rec.ts;
@@ -1270,7 +1264,6 @@ process_cap_file(const char *filename, bool need_separator)
         wtap_rec_reset(&rec);
     } /* while */
     wtap_rec_cleanup(&rec);
-    ws_buffer_free(&buf);
 
     /*
      * Get IDB info strings.
@@ -1461,54 +1454,28 @@ print_usage(FILE *output)
     fprintf(output, "output format.\n");
 }
 
-/*
- * Report an error in command-line arguments.
- */
-static void
-capinfos_cmdarg_err(const char *msg_format, va_list ap)
-{
-    fprintf(stderr, "capinfos: ");
-    vfprintf(stderr, msg_format, ap);
-    fprintf(stderr, "\n");
-}
-
-/*
- * Report additional information for an error in command-line arguments.
- */
-static void
-capinfos_cmdarg_err_cont(const char *msg_format, va_list ap)
-{
-    vfprintf(stderr, msg_format, ap);
-    fprintf(stderr, "\n");
-}
-
 int
 main(int argc, char *argv[])
 {
     char  *configuration_init_error;
-    static const struct report_message_routines capinfos_report_routines = {
-        failure_message,
-        failure_message,
-        open_failure_message,
-        read_failure_message,
-        write_failure_message,
-        cfile_open_failure_message,
-        cfile_dump_open_failure_message,
-        cfile_read_failure_message,
-        cfile_write_failure_message,
-        cfile_close_failure_message
-    };
     bool need_separator = false;
     int    opt;
     int    overall_error_status = EXIT_SUCCESS;
     static const struct ws_option long_options[] = {
         {"help", ws_no_argument, NULL, 'h'},
         {"version", ws_no_argument, NULL, 'v'},
+        LONGOPT_WSLOG
         {0, 0, 0, 0 }
     };
 
+#define OPTSTRING "abcdehiklmnopqrstuvxyzABCDEFHIKLMNPQRST"
+    static const char optstring[] = OPTSTRING;
+
     int status = 0;
 
+    /* Set the program name. */
+    g_set_prgname("capinfos");
+
     /*
      * Set the C-language locale to the native environment and set the
      * code page to UTF-8 on Windows.
@@ -1519,22 +1486,19 @@ main(int argc, char *argv[])
     setlocale(LC_ALL, "");
 #endif
 
-    cmdarg_err_init(capinfos_cmdarg_err, capinfos_cmdarg_err_cont);
+    cmdarg_err_init(stderr_cmdarg_err, stderr_cmdarg_err_cont);
 
     /* Initialize log handler early so we can have proper logging during startup. */
-    ws_log_init("capinfos", vcmdarg_err);
+    ws_log_init(vcmdarg_err);
 
     /* Early logging command-line initialization. */
-    ws_log_parse_args(&argc, argv, vcmdarg_err, WS_EXIT_INVALID_OPTION);
+    ws_log_parse_args(&argc, argv, optstring, long_options, vcmdarg_err, WS_EXIT_INVALID_OPTION);
 
     ws_noisy("Finished log init and parsing command line log arguments");
 
     /* Get the decimal point. */
     decimal_point = g_strdup(localeconv()->decimal_point);
 
-    /* Initialize the version information. */
-    ws_init_version_info("Capinfos", NULL, NULL);
-
 #ifdef _WIN32
     create_app_running_mutex();
 #endif /* _WIN32 */
@@ -1548,7 +1512,7 @@ main(int argc, char *argv[])
      * Attempt to get the pathname of the directory containing the
      * executable file.
      */
-    configuration_init_error = configuration_init(argv[0], NULL);
+    configuration_init_error = configuration_init(argv[0]);
     if (configuration_init_error != NULL) {
         fprintf(stderr,
                 "capinfos: Can't get pathname of directory containing the capinfos program: %s.\n",
@@ -1556,12 +1520,15 @@ main(int argc, char *argv[])
         g_free(configuration_init_error);
     }
 
-    init_report_message("capinfos", &capinfos_report_routines);
+    /* Initialize the version information. */
+    ws_init_version_info("Capinfos", NULL, NULL);
+
+    init_report_failure_message("capinfos");
 
     wtap_init(true);
 
     /* Process the options */
-    while ((opt = ws_getopt_long(argc, argv, "abcdehiklmnopqrstuvxyzABCDEFHIKLMNPQRST", long_options, NULL)) !=-1) {
+    while ((opt = ws_getopt_long(argc, argv, optstring, long_options, NULL)) !=-1) {
 
         switch (opt) {
 
