@@ -11,10 +11,8 @@
 #ifndef PACKET_DPAUX_H
 #define PACKET_DPAUX_H
 
-extern int proto_dpaux;
-
 struct dpaux_info {
-	gboolean from_source;
+	bool from_source;
 };
 
 #endif
