@@ -401,7 +401,7 @@ const value_string E164_ISO3166_country_code_short_value[] = {
 };
 value_string_ext E164_ISO3166_country_code_short_value_ext = VALUE_STRING_EXT_INIT(E164_ISO3166_country_code_short_value);
 
-const value_string E164_GMSS_vals[] = {
+static const value_string E164_GMSS_vals[] = {
 	{ 6,	"Iridium Satellite LLC"},
 	{ 7,	"Iridium Satellite LLC"},
 	{ 8,	"Globalstar"},
@@ -409,7 +409,7 @@ const value_string E164_GMSS_vals[] = {
 	{ 0,	NULL }
 };
 
-const value_string E164_International_Networks_882_vals[] = {
+static const value_string E164_International_Networks_882_vals[] = {
 	{ 10,	"Global Office Application"},
 	{ 12,	"HyperStream International (HSI) Data Network"},
 	{ 13,	"EMS Regional Mobile Satellite System"},
@@ -442,7 +442,7 @@ const value_string E164_International_Networks_882_vals[] = {
 };
 static value_string_ext E164_International_Networks_882_vals_ext = VALUE_STRING_EXT_INIT(E164_International_Networks_882_vals);
 
-const value_string E164_International_Networks_883_vals[] = {
+static const value_string E164_International_Networks_883_vals[] = {
 	{ 100,	"MediaLincc Ltd"},
 	{ 110,	"Aicent Inc"},
 	{ 120,	"Telenor Connexion AB"},
@@ -450,7 +450,7 @@ const value_string E164_International_Networks_883_vals[] = {
 	{ 140,	"Multiregional TransitTelecom (MTT)"},
 	{ 150,	"BodyTrace Netherlands B.V"},
 	{ 5100,	"Voxbone SA"},
-	{ 5110,	"Bandwith.com Inc"},
+	{ 5110,	"Bandwidth.com Inc"},
 	{ 5120,	"MTX Connect Ltd"},
 	{ 5130,	"SIMPE Ltd"},
 	{ 5140,	"Ellipsat Inc"},
@@ -458,17 +458,18 @@ const value_string E164_International_Networks_883_vals[] = {
 	{ 0,	NULL }
 };
 
-static int proto_e164				= -1;
-static int hf_E164_calling_party_number		= -1;
-static int hf_E164_called_party_number		= -1;
-static int hf_E164_number			= -1;
-static int hf_E164_identification_code		= -1;
-static int hf_E164_country_code			= -1;
+static int proto_e164;
+static int hf_E164_calling_party_number;
+static int hf_E164_called_party_number;
+static int hf_E164_msisdn;
+static int hf_E164_isdn;
+static int hf_E164_identification_code;
+static int hf_E164_country_code;
 
-static int ett_e164_msisdn = -1;
+static int ett_e164_msisdn;
 
-static expert_field ei_E164_country_code_non_decimal = EI_INIT;
-static expert_field ei_E164_identification_code_non_decimal = EI_INIT;
+static expert_field ei_E164_country_code_non_decimal;
+static expert_field ei_E164_identification_code_non_decimal;
 
 void
 dissect_e164_number(tvbuff_t *tvb, proto_tree *tree, int offset, int length, e164_info_t e164_info)
@@ -491,7 +492,7 @@ dissect_e164_number(tvbuff_t *tvb, proto_tree *tree, int offset, int length, e16
 	}
 
 	if (e164_info.nature_of_address == E164_NA_INTERNATIONAL_NUMBER) {
-		pi = proto_tree_add_string(tree, hf_E164_number, tvb, offset, length, e164_info.E164_number_str);
+		pi = proto_tree_add_string(tree, hf_E164_msisdn, tvb, offset, length, e164_info.E164_number_str);
 		proto_item_set_hidden(pi);
 	}
 }
@@ -500,17 +501,17 @@ dissect_e164_number(tvbuff_t *tvb, proto_tree *tree, int offset, int length, e16
  * Convert 16bit integer in BCD encoding to decimal.
  * @param bcd		BCD value to convert.
  * @param[out] dec	Pointer to decimal result.
- * @return TRUE if ok, FALSE if bcd contains a nibble > 9.
+ * @return true if ok, false if bcd contains a nibble > 9.
  */
-static gboolean
-convert_bcd_to_dec(guint16 bcd, guint16 * dec)
+static bool
+convert_bcd_to_dec(uint16_t bcd, uint16_t * dec)
 {
-	gboolean rok = TRUE;
-	guint16 result = 0;
-	guint16 mult = 1;
+	bool rok = true;
+	uint16_t result = 0;
+	uint16_t mult = 1;
 	while (bcd) {
 		if ((bcd & 0x0f) > 9)
-			rok = FALSE;
+			rok = false;
 		result += (bcd & 0x0f) * mult;
 		bcd >>= 4;
 		mult *= 10;
@@ -520,19 +521,19 @@ convert_bcd_to_dec(guint16 bcd, guint16 * dec)
 }
 
 void
-dissect_e164_cc(tvbuff_t *tvb, proto_tree *tree, int offset, e164_encoding_t encoding)
+dissect_e164_cc(tvbuff_t *tvb, packet_info* pinfo, proto_tree *tree, int offset, e164_encoding_t encoding)
 {
 	int	cc_offset;
-	guint8	address_digit_pair;
-	guint16	id_code = 0;
-	guint8	cc_length;
-	guint8	length;
-	guint16 cc = 0;
-	gboolean bcd_ok = FALSE;
+	uint8_t	address_digit_pair;
+	uint16_t	id_code = 0;
+	uint8_t	cc_length;
+	uint8_t	length;
+	uint16_t cc = 0;
+	bool bcd_ok = false;
 	proto_item *item = NULL;
 
 	cc_offset = offset;
-	address_digit_pair = tvb_get_guint8(tvb, cc_offset);
+	address_digit_pair = tvb_get_uint8(tvb, cc_offset);
 
 	/* Get the first 3 digits of the MSISDN */
 	switch (encoding) {
@@ -540,7 +541,7 @@ dissect_e164_cc(tvbuff_t *tvb, proto_tree *tree, int offset, e164_encoding_t enc
 		/* Dissect country code after removing non significant zeros */
 		while (address_digit_pair == 0) {
 			cc_offset = cc_offset + 1;
-			address_digit_pair = tvb_get_guint8(tvb, cc_offset);
+			address_digit_pair = tvb_get_uint8(tvb, cc_offset);
 		}
 		cc = tvb_get_ntohs(tvb, cc_offset);
 		if ((address_digit_pair & 0xf0) != 0) {
@@ -553,15 +554,15 @@ dissect_e164_cc(tvbuff_t *tvb, proto_tree *tree, int offset, e164_encoding_t enc
 		cc = cc | (address_digit_pair &0xf0)>>4;
 		cc = cc << 4;
 		if (tvb_bytes_exist(tvb, cc_offset+1, 1)) {
-			address_digit_pair = tvb_get_guint8(tvb, cc_offset+1);
+			address_digit_pair = tvb_get_uint8(tvb, cc_offset+1);
 			cc = cc | (address_digit_pair &0x0f);
 		}
 		break;
 	case E164_ENC_UTF8:
 		/* XXX - do we need to worry about leading 0s? */
-		cc  = (tvb_get_guint8(tvb, cc_offset)   - '0') << 8;
-		cc |= (tvb_get_guint8(tvb, cc_offset+1) - '0') << 4;
-		cc |= (tvb_get_guint8(tvb, cc_offset+2) - '0');
+		cc  = (tvb_get_uint8(tvb, cc_offset)   - '0') << 8;
+		cc |= (tvb_get_uint8(tvb, cc_offset+1) - '0') << 4;
+		cc |= (tvb_get_uint8(tvb, cc_offset+2) - '0');
 		break;
 	}
 
@@ -697,7 +698,7 @@ dissect_e164_cc(tvbuff_t *tvb, proto_tree *tree, int offset, e164_encoding_t enc
 	else
 	    item = proto_tree_add_uint(tree, hf_E164_country_code, tvb, cc_offset, length, cc);
 	if (!bcd_ok) {
-		expert_add_info(NULL, item, &ei_E164_country_code_non_decimal);
+		expert_add_info(pinfo, item, &ei_E164_country_code_non_decimal);
 	}
 
 	/* Handle special Country Codes */
@@ -706,20 +707,20 @@ dissect_e164_cc(tvbuff_t *tvb, proto_tree *tree, int offset, e164_encoding_t enc
 		/* Get the 1-digit ID code */
 		switch (encoding) {
 		case E164_ENC_BINARY:
-			id_code = tvb_get_guint8(tvb, cc_offset + 1) & 0x0f;
+			id_code = tvb_get_uint8(tvb, cc_offset + 1) & 0x0f;
 			break;
 		case E164_ENC_BCD:
-			id_code = (tvb_get_guint8(tvb, cc_offset + 1) & 0xf0) >> 4;
+			id_code = (tvb_get_uint8(tvb, cc_offset + 1) & 0xf0) >> 4;
 			break;
 		case E164_ENC_UTF8:
-			id_code = tvb_get_guint8(tvb, cc_offset + cc_length) - '0';
+			id_code = tvb_get_uint8(tvb, cc_offset + cc_length) - '0';
 			break;
 		}
 		bcd_ok = (id_code <= 9);
 		item = proto_tree_add_uint_format_value(tree, hf_E164_identification_code, tvb, (cc_offset + 1), 1,
 						id_code, "%d %s", id_code, val_to_str_const(id_code, E164_GMSS_vals, "Unknown"));
 		if (!bcd_ok) {
-			expert_add_info(NULL, item, &ei_E164_identification_code_non_decimal);
+			expert_add_info(pinfo, item, &ei_E164_identification_code_non_decimal);
 		}
 		break;
 	case 882:
@@ -730,19 +731,19 @@ dissect_e164_cc(tvbuff_t *tvb, proto_tree *tree, int offset, e164_encoding_t enc
 			id_code = (id_code & 0x0ff0) >> 4;
 			break;
 		case E164_ENC_BCD:
-			id_code  = tvb_get_guint8(tvb, cc_offset + 1) & 0xf0;
-			id_code |= tvb_get_guint8(tvb, cc_offset + 2) & 0x0f;
+			id_code  = tvb_get_uint8(tvb, cc_offset + 1) & 0xf0;
+			id_code |= tvb_get_uint8(tvb, cc_offset + 2) & 0x0f;
 			break;
 		case E164_ENC_UTF8:
-			id_code  = (tvb_get_guint8(tvb, cc_offset+cc_length)   - '0') << 4;
-			id_code |= (tvb_get_guint8(tvb, cc_offset+cc_length+1) - '0');
+			id_code  = (tvb_get_uint8(tvb, cc_offset+cc_length)   - '0') << 4;
+			id_code |= (tvb_get_uint8(tvb, cc_offset+cc_length+1) - '0');
 			break;
 		}
 		bcd_ok = convert_bcd_to_dec(id_code, &id_code);
 		item = proto_tree_add_uint_format_value(tree, hf_E164_identification_code, tvb, (cc_offset + 1), 2,
 						id_code, "%d %s", id_code, val_to_str_ext_const(id_code, &E164_International_Networks_882_vals_ext, "Unknown"));
 		if (!bcd_ok) {
-			expert_add_info(NULL, item, &ei_E164_identification_code_non_decimal);
+			expert_add_info(pinfo, item, &ei_E164_identification_code_non_decimal);
 		}
 		break;
 	case 883:
@@ -753,41 +754,41 @@ dissect_e164_cc(tvbuff_t *tvb, proto_tree *tree, int offset, e164_encoding_t enc
 			id_code = id_code & 0x0fff;
 			break;
 		case E164_ENC_BCD:
-			id_code  = (tvb_get_guint8(tvb, cc_offset + 1) & 0xf0) << 4;
-			id_code |= (tvb_get_guint8(tvb, cc_offset + 2) & 0x0f) << 4;
-			id_code |= (tvb_get_guint8(tvb, cc_offset + 2) & 0xf0) >> 4;
+			id_code  = (tvb_get_uint8(tvb, cc_offset + 1) & 0xf0) << 4;
+			id_code |= (tvb_get_uint8(tvb, cc_offset + 2) & 0x0f) << 4;
+			id_code |= (tvb_get_uint8(tvb, cc_offset + 2) & 0xf0) >> 4;
 			break;
 		case E164_ENC_UTF8:
-			id_code  = (tvb_get_guint8(tvb, cc_offset+cc_length)   - '0') << 8;
-			id_code |= (tvb_get_guint8(tvb, cc_offset+cc_length+1) - '0') << 4;
-			id_code |= (tvb_get_guint8(tvb, cc_offset+cc_length+2) - '0');
+			id_code  = (tvb_get_uint8(tvb, cc_offset+cc_length)   - '0') << 8;
+			id_code |= (tvb_get_uint8(tvb, cc_offset+cc_length+1) - '0') << 4;
+			id_code |= (tvb_get_uint8(tvb, cc_offset+cc_length+2) - '0');
 			break;
 		}
 		if ((id_code & 0x0ff0) == 0x510) {
 			/* Get the 4th digit of the ID code */
 			switch (encoding) {
 			case E164_ENC_BINARY:
-				id_code = (id_code << 4) | ((tvb_get_guint8(tvb, cc_offset + 3) & 0xf0) >> 4);
+				id_code = (id_code << 4) | ((tvb_get_uint8(tvb, cc_offset + 3) & 0xf0) >> 4);
 				break;
 			case E164_ENC_BCD:
-				id_code = (id_code << 4) | (tvb_get_guint8(tvb, cc_offset + 3) & 0x0f);
+				id_code = (id_code << 4) | (tvb_get_uint8(tvb, cc_offset + 3) & 0x0f);
 				break;
 			case E164_ENC_UTF8:
-				id_code = (id_code << 4) | (tvb_get_guint8(tvb, cc_offset + cc_length + 3) - '0');
+				id_code = (id_code << 4) | (tvb_get_uint8(tvb, cc_offset + cc_length + 3) - '0');
 				break;
 			}
 			bcd_ok = convert_bcd_to_dec(id_code, &id_code);
 			item = proto_tree_add_uint_format_value(tree, hf_E164_identification_code, tvb, (cc_offset + 1), 3,
 					id_code, "%d %s", id_code, val_to_str_const(id_code, E164_International_Networks_883_vals, "Unknown"));
 			if (!bcd_ok) {
-				expert_add_info(NULL, item, &ei_E164_identification_code_non_decimal);
+				expert_add_info(pinfo, item, &ei_E164_identification_code_non_decimal);
 			}
 		} else {
 			bcd_ok = convert_bcd_to_dec(id_code, &id_code);
 			item = proto_tree_add_uint_format_value(tree, hf_E164_identification_code, tvb, (cc_offset + 1), 2,
 					id_code, "%d %s", id_code, val_to_str_const(id_code, E164_International_Networks_883_vals, "Unknown"));
 			if (!bcd_ok) {
-				expert_add_info(NULL, item, &ei_E164_identification_code_non_decimal);
+				expert_add_info(pinfo, item, &ei_E164_identification_code_non_decimal);
 			}
 		}
 		break;
@@ -797,33 +798,45 @@ dissect_e164_cc(tvbuff_t *tvb, proto_tree *tree, int offset, e164_encoding_t enc
 
 }
 
-const gchar *
-dissect_e164_msisdn(tvbuff_t *tvb, proto_tree *tree, int offset, int length, e164_encoding_t encoding)
+static const char *
+dissect_e164(tvbuff_t *tvb, packet_info* pinfo, proto_tree *tree, int offset, int length, e164_encoding_t encoding, int name_type)
 {
 	proto_item *pi;
 	proto_tree *subtree;
-	guint       str_encoding;
-	char       *msisdn_str;
+	unsigned    str_encoding;
+	char       *number_str;
 
 	switch (encoding) {
 	case E164_ENC_UTF8:
 		str_encoding = ENC_UTF_8;
 		break;
 	case E164_ENC_BCD:
-		str_encoding = ENC_BCD_DIGITS_0_9;
+		str_encoding = ENC_BCD_DIGITS_0_9|ENC_LITTLE_ENDIAN;
 		break;
 	case E164_ENC_BINARY:
 	default:
 		DISSECTOR_ASSERT_NOT_REACHED();
 	}
 
-	pi = proto_tree_add_item_ret_display_string(tree, hf_E164_number, tvb, offset, length, str_encoding, wmem_packet_scope(), &msisdn_str);
+	pi = proto_tree_add_item_ret_display_string(tree, name_type, tvb, offset, length, str_encoding, pinfo->pool, &number_str);
 
 	subtree = proto_item_add_subtree(pi, ett_e164_msisdn);
 
-	dissect_e164_cc(tvb, subtree, offset, encoding);
+	dissect_e164_cc(tvb, pinfo, subtree, offset, encoding);
 
-	return msisdn_str;
+	return number_str;
+}
+
+const char *
+dissect_e164_msisdn(tvbuff_t *tvb, packet_info* pinfo, proto_tree *tree, int offset, int length, e164_encoding_t encoding)
+{
+	return dissect_e164(tvb, pinfo, tree, offset, length, encoding, hf_E164_msisdn);
+}
+
+const char *
+dissect_e164_isdn(tvbuff_t *tvb, packet_info* pinfo, proto_tree *tree, int offset, int length, e164_encoding_t encoding)
+{
+	return dissect_e164(tvb, pinfo, tree, offset, length, encoding, hf_E164_isdn);
 }
 
 /*
@@ -846,11 +859,16 @@ proto_register_e164(void)
 		  FT_STRING, BASE_NONE, NULL, 0x0,
 			NULL, HFILL }},
 
-		{ &hf_E164_number,
+		{ &hf_E164_msisdn,
 		  { "E.164 number (MSISDN)", "e164.msisdn",
 		  FT_STRING, BASE_NONE, NULL, 0x0,
 			NULL, HFILL }},
 
+		{ &hf_E164_isdn,
+		  { "E.164 number (ISDN)", "e164.isdn",
+		  FT_STRING, BASE_NONE, NULL, 0x0,
+			NULL, HFILL }},
+
 		{ &hf_E164_identification_code,
 		  { "Identification Code", "e164.identification_code",
 		  FT_UINT32, BASE_DEC, NULL, 0x0,
@@ -862,7 +880,7 @@ proto_register_e164(void)
 			NULL, HFILL }},
 	};
 
-	static gint *ett_e164_array[] = {
+	static int *ett_e164_array[] = {
 	    &ett_e164_msisdn,
 	};
 
