@@ -21,6 +21,7 @@
 #include <epan/conversation_filter.h>
 #include <epan/capture_dissectors.h>
 #include <epan/exported_pdu.h>
+#include <epan/tfs.h>
 #include <wsutil/pint.h>
 #include "packet-eth.h"
 #include "packet-gre.h"
@@ -235,7 +236,7 @@ capture_eth(const unsigned char *pd, int offset, int len, capture_packet_info_t
   if (!BYTES_ARE_IN_FRAME(offset, len, ETH_HEADER_SIZE))
     return false;
 
-  etype = pntoh16(&pd[offset+12]);
+  etype = pntohu16(&pd[offset+12]);
 
   if (etype <= IEEE_802_3_MAX_LEN) {
     /* Oh, yuck.  Cisco ISL frames require special interpretation of the
@@ -452,8 +453,16 @@ dissect_eth_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree,
    * Ethernet framing, allow heuristic dissectors to take
    * a first look before we assume that it's actually an
    * Ethernet packet.
+   *
+   * Tell the heuristic dissectors what FCS length was reported for
+   * this packet - the non-Ethernet packet might or might not include
+   * the FCS, or might have a different calculation. (Heuristic
+   * dissectors also can't report a number of bytes consumed, so we
+   * can't really handle the "maybefcs" case otherwise.)
    */
-  if (dissector_try_heuristic(heur_subdissector_list, tvb, pinfo, parent_tree, &hdtbl_entry, NULL))
+  struct eth_phdr    phdr;
+  phdr.fcs_len = fcs_len;
+  if (dissector_try_heuristic(heur_subdissector_list, tvb, pinfo, parent_tree, &hdtbl_entry, &phdr))
     return fh_tree;
 
   if (ehdr->type <= IEEE_802_3_MAX_LEN) {
