@@ -185,7 +185,10 @@
 #include <epan/expert.h>
 #include <epan/proto_data.h>
 
-#include <wsutil/utf8_entities.h>
+#include <epan/tfs.h>
+#include <epan/unit_strings.h>
+
+#include <wsutil/array.h>
 #include <wiretap/wtap.h>
 
 #include "packet-btle.h"
@@ -306,7 +309,7 @@ dissect_lengths(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree,
     switch (nordic_ble_context->protover) {
     case 0:  /* Legacy version */
         hlen = 2 + UART_HEADER_LEN; /* 2 bytes legacy marker + UART header */
-        item = proto_tree_add_item_ret_uint(tree, hf_nordic_ble_payload_length, tvb, offset, 1, ENC_NA, &plen);
+        item = proto_tree_add_item_ret_uint(tree, hf_nordic_ble_payload_length, tvb, offset, 1, ENC_BIG_ENDIAN, &plen);
         offset += 1;
         break;
 
@@ -315,7 +318,7 @@ dissect_lengths(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree,
         hlen += 1; /* Add one byte for board id */
         offset += 1;
 
-        item = proto_tree_add_item_ret_uint(tree, hf_nordic_ble_payload_length, tvb, offset, 1, ENC_NA, &plen);
+        item = proto_tree_add_item_ret_uint(tree, hf_nordic_ble_payload_length, tvb, offset, 1, ENC_BIG_ENDIAN, &plen);
         offset += 1;
         break;
 
@@ -828,7 +831,7 @@ proto_register_nordic_ble(void)
         },
         { &hf_nordic_ble_packet_length,
             { "Length of packet", "nordic_ble.len",
-                FT_UINT16, BASE_DEC, NULL, 0x0,
+                FT_UINT8, BASE_DEC, NULL, 0x0,
                 NULL, HFILL }
         },
         { &hf_nordic_ble_flags,
@@ -898,7 +901,7 @@ proto_register_nordic_ble(void)
         },
         { &hf_nordic_ble_rssi,
             { "RSSI", "nordic_ble.rssi",
-                FT_INT8, BASE_DEC | BASE_UNIT_STRING, &units_dbm, 0x0,
+                FT_INT8, BASE_DEC | BASE_UNIT_STRING, UNS(&units_dbm), 0x0,
                 "Received Signal Strength Indicator", HFILL }
         },
         { &hf_nordic_ble_event_counter,
@@ -908,22 +911,22 @@ proto_register_nordic_ble(void)
         },
         { &hf_nordic_ble_time,
             { "Timestamp", "nordic_ble.time",
-                FT_UINT32, BASE_DEC | BASE_UNIT_STRING, &units_microseconds, 0x0,
+                FT_UINT32, BASE_DEC | BASE_UNIT_STRING, UNS(&units_microseconds), 0x0,
                 "Firmware timestamp", HFILL }
         },
         { &hf_nordic_ble_delta_time,
             { "Delta time (end to start)", "nordic_ble.delta_time",
-                FT_UINT32, BASE_DEC | BASE_UNIT_STRING, &units_microseconds, 0x0,
+                FT_UINT32, BASE_DEC | BASE_UNIT_STRING, UNS(&units_microseconds), 0x0,
                 "Time since end of last reported packet", HFILL }
         },
         { &hf_nordic_ble_delta_time_ss,
             { "Delta time (start to start)", "nordic_ble.delta_time_ss",
-                FT_UINT32, BASE_DEC | BASE_UNIT_STRING, &units_microseconds, 0x0,
+                FT_UINT32, BASE_DEC | BASE_UNIT_STRING, UNS(&units_microseconds), 0x0,
                 "Time since start of last reported packet", HFILL }
         },
         { &hf_nordic_ble_packet_time,
             { "Packet time (start to end)", "nordic_ble.packet_time",
-                FT_UINT32, BASE_DEC | BASE_UNIT_STRING, &units_microseconds, 0x0,
+                FT_UINT32, BASE_DEC | BASE_UNIT_STRING, UNS(&units_microseconds), 0x0,
                 "Time of packet", HFILL }
         },
     };
