@@ -18,10 +18,14 @@
 #include <epan/expert.h>
 #include <epan/to_str.h>
 #include <epan/cisco_pid.h>
+#include <epan/tfs.h>
+#include <wsutil/array.h>
 
 void proto_register_pagp(void);
 void proto_reg_handoff_pagp(void);
 
+static dissector_handle_t pagp_handle;
+
 /* Offsets of fields within a PagP PDU */
 
 #define PAGP_VERSION_NUMBER              0
@@ -68,45 +72,45 @@ void proto_reg_handoff_pagp(void);
 
 /* Initialise the protocol and registered fields */
 
-static int proto_pagp = -1;
+static int proto_pagp;
 
-static int hf_pagp_version_number = -1;
+static int hf_pagp_version_number;
 
-static int hf_pagp_flags = -1;
-static int hf_pagp_flags_slow_hello = -1;
-static int hf_pagp_flags_auto_mode = -1;
-static int hf_pagp_flags_consistent_state = -1;
-static int hf_pagp_local_device_id = -1;
-static int hf_pagp_local_learn_cap = -1;
-static int hf_pagp_local_port_priority = -1;
-static int hf_pagp_local_sent_port_ifindex = -1;
-static int hf_pagp_local_group_capability = -1;
-static int hf_pagp_local_group_ifindex = -1;
-static int hf_pagp_partner_device_id = -1;
-static int hf_pagp_partner_learn_cap = -1;
-static int hf_pagp_partner_port_priority = -1;
-static int hf_pagp_partner_sent_port_ifindex = -1;
-static int hf_pagp_partner_group_capability = -1;
-static int hf_pagp_partner_group_ifindex = -1;
-static int hf_pagp_partner_count = -1;
-static int hf_pagp_num_tlvs = -1;
-static int hf_pagp_tlv = -1;
-static int hf_pagp_tlv_length = -1;
-static int hf_pagp_tlv_device_name = -1;
-static int hf_pagp_tlv_port_name = -1;
-static int hf_pagp_tlv_agport_mac = -1;
+static int hf_pagp_flags;
+static int hf_pagp_flags_slow_hello;
+static int hf_pagp_flags_auto_mode;
+static int hf_pagp_flags_consistent_state;
+static int hf_pagp_local_device_id;
+static int hf_pagp_local_learn_cap;
+static int hf_pagp_local_port_priority;
+static int hf_pagp_local_sent_port_ifindex;
+static int hf_pagp_local_group_capability;
+static int hf_pagp_local_group_ifindex;
+static int hf_pagp_partner_device_id;
+static int hf_pagp_partner_learn_cap;
+static int hf_pagp_partner_port_priority;
+static int hf_pagp_partner_sent_port_ifindex;
+static int hf_pagp_partner_group_capability;
+static int hf_pagp_partner_group_ifindex;
+static int hf_pagp_partner_count;
+static int hf_pagp_num_tlvs;
+static int hf_pagp_tlv;
+static int hf_pagp_tlv_length;
+static int hf_pagp_tlv_device_name;
+static int hf_pagp_tlv_port_name;
+static int hf_pagp_tlv_agport_mac;
 
-static int hf_pagp_flush_local_device_id = -1;
-static int hf_pagp_flush_partner_device_id = -1;
-static int hf_pagp_flush_transaction_id = -1;
+static int hf_pagp_flush_local_device_id;
+static int hf_pagp_flush_partner_device_id;
+static int hf_pagp_flush_transaction_id;
 
 /* Initialise the subtree pointers */
 
-static gint ett_pagp = -1;
-static gint ett_pagp_flags = -1;
-static gint ett_pagp_tlvs = -1;
+static int ett_pagp;
+static int ett_pagp_flags;
+static int ett_pagp_tlvs;
 
-static expert_field ei_pagp_tlv_length = EI_INIT;
+static expert_field ei_pagp_tlv_length;
 
 /* General declarations and macros */
 
@@ -139,15 +143,15 @@ static const true_false_string automode = {
 static int
 dissect_pagp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 {
-    guint32 raw_word;
-    guint16 num_tlvs;
-    guint16 tlv;
-    guint16 len;
-    guint16 ii;
-    guint16 offset = PAGP_FIRST_TLV;
-    guint8  raw_octet;
+    uint32_t raw_word;
+    uint16_t num_tlvs;
+    uint16_t tlv;
+    uint16_t len;
+    uint16_t ii;
+    uint16_t offset = PAGP_FIRST_TLV;
+    uint8_t raw_octet;
 
-    guint8  flags;
+    uint8_t flags;
 
     proto_tree *pagp_tree = NULL;
     proto_item *pagp_item, *len_item;
@@ -164,7 +168,7 @@ dissect_pagp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_
 
     col_clear(pinfo->cinfo, COL_INFO);
 
-    raw_octet = tvb_get_guint8(tvb, PAGP_VERSION_NUMBER);
+    raw_octet = tvb_get_uint8(tvb, PAGP_VERSION_NUMBER);
     if (tree) {
         pagp_item = proto_tree_add_protocol_format(tree, proto_pagp, tvb,
                                                    0, -1, "Port Aggregation Protocol");
@@ -199,7 +203,7 @@ dissect_pagp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_
 
     /* Info PDU */
 
-    flags = tvb_get_guint8(tvb, PAGP_FLAGS);
+    flags = tvb_get_uint8(tvb, PAGP_FLAGS);
     col_append_fstr(pinfo->cinfo, COL_INFO, "; Flags 0x%x", flags);
 
     proto_tree_add_bitmask(pagp_tree, tvb, PAGP_FLAGS, hf_pagp_flags, ett_pagp_flags, pagp_flags, ENC_NA);
@@ -281,11 +285,11 @@ dissect_pagp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_
         switch (tlv) {
             case PAGP_TLV_DEVICE_NAME:
                 proto_tree_add_item(tlv_tree, hf_pagp_tlv_device_name,
-                                      tvb, offset+4, len-4, ENC_NA|ENC_ASCII);
+                                    tvb, offset+4, len-4, ENC_ASCII);
                 break;
             case PAGP_TLV_PORT_NAME:
                 proto_tree_add_item(tlv_tree, hf_pagp_tlv_port_name,
-                                      tvb, offset+4, len-4, ENC_NA|ENC_ASCII);
+                                    tvb, offset+4, len-4, ENC_ASCII);
                 break;
             case PAGP_TLV_AGPORT_MAC:
                 proto_tree_add_item(tlv_tree, hf_pagp_tlv_agport_mac,
@@ -450,7 +454,7 @@ proto_register_pagp(void)
 
     /* Setup protocol subtree array */
 
-    static gint *ett[] = {
+    static int *ett[] = {
         &ett_pagp,
         &ett_pagp_flags,
         &ett_pagp_tlvs,
@@ -471,15 +475,13 @@ proto_register_pagp(void)
     proto_register_subtree_array(ett, array_length(ett));
     expert_pagp = expert_register_protocol(proto_pagp);
     expert_register_field_array(expert_pagp, ei, array_length(ei));
+    pagp_handle = register_dissector("pagp", dissect_pagp, proto_pagp);
 }
 
 
 void
 proto_reg_handoff_pagp(void)
 {
-    dissector_handle_t pagp_handle;
-
-    pagp_handle = create_dissector_handle(dissect_pagp, proto_pagp);
     dissector_add_uint("llc.cisco_pid", CISCO_PID_PAGP, pagp_handle);
 }
 
