@@ -80,15 +80,15 @@ static expert_field ei_proxy_header_length_too_small;
 static expert_field ei_proxy_bad_format;
 
 
-static gint ett_proxy1;
-static gint ett_proxy2;
-static gint ett_proxy2_fampro;
-static gint ett_proxy2_tlv;
+static int ett_proxy1;
+static int ett_proxy2;
+static int ett_proxy2_fampro;
+static int ett_proxy2_tlv;
 
 static dissector_handle_t proxy_v1_handle;
 static dissector_handle_t proxy_v2_handle;
 
-static const guint8 proxy_v2_magic[] = { 0x0d, 0x0a, 0x0d, 0x0a, 0x00, 0x0d, 0x0a, 0x51, 0x55, 0x49, 0x54, 0x0a };
+static const uint8_t proxy_v2_magic[] = { 0x0d, 0x0a, 0x0d, 0x0a, 0x00, 0x0d, 0x0a, 0x51, 0x55, 0x49, 0x54, 0x0a };
 
 static const value_string proxy2_cmd_vals[] = {
     { 0x0, "LOCAL" },
@@ -198,7 +198,7 @@ dissect_proxy_proxied(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree,
         if (addresses_equal(&pinfo->src, conversation_key_addr1(conv->key_ptr)) &&
             (pinfo->srcport == conversation_key_port1(conv->key_ptr))) {
             conversation_set_conv_addr_port_endpoints(pinfo, &proxy_info->src, &proxy_info->dst,
-                conversation_pt_to_conversation_type(proxy_info->ptype), proxy_info->srcport,
+                CONVERSATION_PROXY, proxy_info->srcport,
                 proxy_info->dstport);
             srcport = proxy_info->srcport;
             dstport = proxy_info->dstport;
@@ -206,7 +206,7 @@ dissect_proxy_proxied(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree,
         }
         else {
             conversation_set_conv_addr_port_endpoints(pinfo, &proxy_info->dst, &proxy_info->src,
-                conversation_pt_to_conversation_type(proxy_info->ptype), proxy_info->dstport,
+                CONVERSATION_PROXY, proxy_info->dstport,
                 proxy_info->srcport);
             srcport = proxy_info->dstport;
             dstport = proxy_info->srcport;
@@ -250,7 +250,7 @@ dissect_proxy_v2_tlv(tvbuff_t *tvb, packet_info *pinfo, proto_tree *proxy_tree,
 {
     increment_dissection_depth(pinfo);
     while (offset < next_offset) {
-        guint32 type, length;
+        uint32_t type, length;
         proto_item *ti_tlv;
         proto_tree *tlv_tree;
 
@@ -269,7 +269,7 @@ dissect_proxy_v2_tlv(tvbuff_t *tvb, packet_info *pinfo, proto_tree *proxy_tree,
         case PP2_TYPE_SSL: /* SSL */
             proto_tree_add_item(tlv_tree, hf_proxy2_tlv_ssl_client, tvb, offset, 1, ENC_NA);
             offset += 1;
-            proto_tree_add_item(tlv_tree, hf_proxy2_tlv_ssl_verify, tvb, offset, 4, ENC_NA);
+            proto_tree_add_item(tlv_tree, hf_proxy2_tlv_ssl_verify, tvb, offset, 4, ENC_BIG_ENDIAN);
             offset += 4;
             offset = dissect_proxy_v2_tlv(tvb, pinfo, tlv_tree, offset, next_offset);
         break;
@@ -305,73 +305,73 @@ dissect_proxy_v2_tlv(tvbuff_t *tvb, packet_info *pinfo, proto_tree *proxy_tree,
     return offset;
 }
 
-static gboolean
+static bool
 is_proxy_v2(tvbuff_t* tvb)
 {
     int offset = 0;
     int length = tvb_reported_length(tvb);
 
     if (length < 16) {
-        return FALSE;
+        return false;
     }
 
-    if (tvb_memeql(tvb, offset, (const guint8*)proxy_v2_magic, sizeof(proxy_v2_magic)) != 0) {
-        return FALSE;
+    if (tvb_memeql(tvb, offset, (const uint8_t*)proxy_v2_magic, sizeof(proxy_v2_magic)) != 0) {
+        return false;
     }
     // TODO maybe check for "(hdr.v2.ver_cmd & 0xF0) == 0x20" as done in "9. Sample code" from
     // https://www.haproxy.org/download/1.8/doc/proxy-protocol.txt?
 
-    return TRUE;
+    return true;
 }
 
 /* "a 108-byte buffer is always enough to store all the line and a trailing zero" */
 #define PROXY_V1_MAX_LINE_LENGTH 107
 
-static gboolean
-is_proxy_v1(tvbuff_t *tvb, gint *header_length)
+static bool
+is_proxy_v1(tvbuff_t *tvb, int *header_length)
 {
     const int min_header_size = sizeof("PROXY \r\n") - 1;
     int length = tvb_reported_length(tvb);
-    gint next_offset;
+    int next_offset;
 
     if (length < min_header_size) {
-        return FALSE;
+        return false;
     }
 
-    if (tvb_memeql(tvb, 0, (const guint8*)"PROXY ", 6) != 0) {
-        return FALSE;
+    if (tvb_memeql(tvb, 0, (const uint8_t*)"PROXY ", 6) != 0) {
+        return false;
     }
 
     length = MIN(length, PROXY_V1_MAX_LINE_LENGTH);
-    if (tvb_find_line_end(tvb, 6, length, &next_offset, FALSE) == -1) {
-        return FALSE;
+    if (tvb_find_line_end(tvb, 6, length, &next_offset, false) == -1) {
+        return false;
     }
 
     /* The line must end with a CRLF and not just a single CR or LF. */
-    if (tvb_memeql(tvb, next_offset - 2, (const guint8*)"\r\n", 2) != 0) {
-        return FALSE;
+    if (tvb_memeql(tvb, next_offset - 2, (const uint8_t*)"\r\n", 2) != 0) {
+        return false;
     }
 
     if (header_length) {
         *header_length = next_offset;
     }
-    return TRUE;
+    return true;
 }
 
 /**
  * Scan for the next non-empty token (terminated by a space). If invalid, add
- * expert info for the remaining part and return FALSE. Otherwise return TRUE
+ * expert info for the remaining part and return false. Otherwise return true
  * and the token length.
  */
-static gboolean
-proxy_v1_get_token_length(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset, int header_length, gchar *token, gint *token_length)
+static bool
+proxy_v1_get_token_length(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset, int header_length, char *token, int *token_length)
 {
-    gint space_pos = tvb_find_guint8(tvb, offset, header_length - offset, ' ');
+    int space_pos = tvb_find_uint8(tvb, offset, header_length - offset, ' ');
     if (space_pos == -1) {
         proto_tree_add_expert(tree, pinfo, &ei_proxy_bad_format, tvb, offset, header_length - offset);
-        return FALSE;
+        return false;
     }
-    gint length = space_pos - offset;
+    int length = space_pos - offset;
     if (token && length) {
         DISSECTOR_ASSERT(length + 1 < PROXY_V1_MAX_LINE_LENGTH);
         tvb_memcpy(tvb, token, offset, length);
@@ -386,13 +386,13 @@ dissect_proxy_v1_header(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
     proto_item *ti;
     proto_tree *proxy_tree;
-    guint       offset = 0;
-    gint        header_length = 0;
-    gint        token_length = 0;
-    gint        tcp_ip_version = 0;
-    guint16     srcport, dstport;
-    gchar       buffer[PROXY_V1_MAX_LINE_LENGTH];
-    guint32     src_ipv4, dst_ipv4;
+    unsigned    offset = 0;
+    int         header_length = 0;
+    int         token_length = 0;
+    int         tcp_ip_version = 0;
+    uint16_t    srcport, dstport;
+    char        buffer[PROXY_V1_MAX_LINE_LENGTH];
+    uint32_t    src_ipv4, dst_ipv4;
     ws_in6_addr src_ipv6, dst_ipv6;
     address     src_addr, dst_addr;
 
@@ -413,7 +413,7 @@ dissect_proxy_v1_header(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     if (!proxy_v1_get_token_length(tvb, pinfo, proxy_tree, offset, header_length, buffer, &token_length)) {
         return tvb_captured_length(tvb);
     }
-    proto_tree_add_item(proxy_tree, hf_proxy1_proto, tvb, offset, token_length, ENC_NA|ENC_ASCII);
+    proto_tree_add_item(proxy_tree, hf_proxy1_proto, tvb, offset, token_length, ENC_ASCII);
     if (token_length == 4) {
         if (memcmp(buffer, "TCP4", 4) == 0) {
             tcp_ip_version = 4;
@@ -481,7 +481,7 @@ dissect_proxy_v1_header(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         break;
 
     default:
-        proto_tree_add_item(proxy_tree, hf_proxy1_unknown, tvb, offset, header_length - 2 - offset, ENC_NA|ENC_ASCII);
+        proto_tree_add_item(proxy_tree, hf_proxy1_unknown, tvb, offset, header_length - 2 - offset, ENC_ASCII);
         return tvb_captured_length(tvb);
     }
 
@@ -553,10 +553,10 @@ dissect_proxy_v2_header(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
     proto_item *ti , *ti_ver;
     proto_tree *proxy_tree, *fampro_tree;
-    guint offset = 0, next_offset;
-    guint32     header_len, fam_pro, cmd;
+    unsigned offset = 0, next_offset;
+    uint32_t    header_len, fam_pro, cmd;
     address     src_addr = ADDRESS_INIT_NONE, dst_addr = ADDRESS_INIT_NONE;
-    guint32     srcport, dstport;
+    uint32_t    srcport, dstport;
     port_type   ptype = PT_NONE;
 
     if (!is_proxy_v2(tvb)) {
@@ -592,10 +592,10 @@ dissect_proxy_v2_header(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     switch (fam_pro){
         case 0x11: /* TCP over IPv4 */
         case 0x12: /* UDP over IPv4 */
-            proto_tree_add_item(proxy_tree, hf_proxy_src_ipv4, tvb, offset, 4, ENC_NA);
+            proto_tree_add_item(proxy_tree, hf_proxy_src_ipv4, tvb, offset, 4, ENC_BIG_ENDIAN);
             set_address_tvb(&src_addr, AT_IPv4, 4, tvb, offset);
             offset += 4;
-            proto_tree_add_item(proxy_tree, hf_proxy_dst_ipv4, tvb, offset, 4, ENC_NA);
+            proto_tree_add_item(proxy_tree, hf_proxy_dst_ipv4, tvb, offset, 4, ENC_BIG_ENDIAN);
             set_address_tvb(&dst_addr, AT_IPv4, 4, tvb, offset);
             offset += 4;
             proto_tree_add_item_ret_uint(proxy_tree, hf_proxy_srcport, tvb, offset, 2, ENC_BIG_ENDIAN, &srcport);
@@ -905,7 +905,7 @@ proto_register_proxy(void)
         },
     };
 
-    static gint *ett[] = {
+    static int *ett[] = {
         &ett_proxy1,
         &ett_proxy2,
         &ett_proxy2_fampro,
