@@ -16,7 +16,7 @@
 #define __PACKET_SDP_H__
 
 typedef struct _sdp_packet_info {
-        gchar summary_str[50];      /* SDP summary string for VoIP calls graph analysis */
+        char summary_str[50];      /* SDP summary string for VoIP calls graph analysis */
 } sdp_packet_info;
 
 enum sdp_exchange_type
@@ -29,27 +29,33 @@ enum sdp_exchange_type
 enum sdp_trace_id_hf_type
 {
     SDP_TRACE_ID_HF_TYPE_STR = 0, /* */
-    SDP_TRACE_ID_HF_TYPE_GUINT32 /* */
+    SDP_TRACE_ID_HF_TYPE_UINT32 /* */
 };
 
 /*
  *  Information needed to set up a trace id in RTP(t ex SIP CallId )
  */
-#define SDP_INFO_OFFSET 10 /* Max number of SDP data occurensies in a single frame */
-
-typedef struct _sdp_conv_info {
-    wmem_array_t *sdp_setup_info_list;
-} sdp_conv_info_t;
+#define SDP_INFO_OFFSET 10 /* Max number of SDP data occurrences in a single frame */
 
 typedef struct _sdp_setup_info {
-    gchar *setup_proto;
     int  hf_id;                         /* Header field to use */
-    enum sdp_trace_id_hf_type hf_type;  /* Indicates which of the following variables to use( add guint32 etc as needed)*/
-    gchar *trace_id;                    /* The trace id if the type is str*/
-    guint32 trace_id_num;               /* Numerical trace id */
+    enum sdp_trace_id_hf_type hf_type;  /* Indicates which of the following variables to use( add uint32_t etc as needed)*/
+    bool add_hidden;
+    bool is_osmux;
+    union {
+        char   *str;                    /* The trace id if the hf_type is str */
+        uint32_t num;                    /* Numerical trace id */
+    } trace_id;
+    const char* base_uri;               /* For RTSP, URIs in the control field can be relative to this. */
 } sdp_setup_info_t;
 
-extern void setup_sdp_transport(tvbuff_t *tvb, packet_info *pinfo, enum sdp_exchange_type type, int request_frame, const gboolean delay, sdp_setup_info_t *setup_info);
+/* opaque outside packet-rtp.c */
+typedef struct _rtp_dyn_payload_t rtp_dyn_payload_t;
+
+extern rtp_dyn_payload_t*
+sdp_get_rtsp_media_desc(const char *control_uri);
+
+extern void setup_sdp_transport(tvbuff_t *tvb, packet_info *pinfo, enum sdp_exchange_type type, int request_frame, const bool delay, sdp_setup_info_t *setup_info);
 /* Handles duplicate OFFER packets so they don't end up processed by dissect_sdp().  This can probably
  * be removed when all higher layer dissectors properly handle SDP themselves with setup_sdp_transport()
  */
