@@ -18,7 +18,7 @@
 /*
  * Modified to support throwing an exception with a null message pointer,
  * and to have the message not be const (as we generate messages with
- * "g_strdup_sprintf()", which means they need to be freed; using
+ * "ws_strdup_printf()", which means they need to be freed; using
  * a null message means that we don't have to use a special string
  * for exceptions with no message, and don't have to worry about
  * not freeing that).
@@ -33,11 +33,9 @@
 #include <limits.h>
 
 #include <glib.h>
+#include <wsutil/ws_assert.h>
 
 #include "except.h"
-#ifdef KAZLIB_TEST_MAIN
-#include <wsutil/ws_printf.h> /* ws_debug_printf */
-#endif
 
 #ifdef _WIN32
 #include <windows.h>
@@ -131,22 +129,31 @@ void except_deinit(void)
     pthread_mutex_unlock(&init_mtx);
 }
 
-#else /* no thread support */
+#else /* not using POSIX thread support */
 
+/*
+ * We make the catcher stack per-thread, because we must.
+ *
+ * We don't make the unhandled-exception-catcher, the allocator, or the
+ * deallocator thread-specific, as we don't need to.
+ *
+ * We don't protext the init level with a mutex, as we only initialize
+ * it and de-initialize it once.
+ */
 static int init_counter;
 static void unhandled_catcher(except_t *);
 static void (*uh_catcher_ptr)(except_t *) = unhandled_catcher;
 /* We need this 'size_t' cast due to a glitch in GLib where g_malloc was prototyped
- * as 'gpointer g_malloc (gulong n_bytes)'. This was later fixed to the correct prototype
- * 'gpointer g_malloc (gsize n_bytes)'. In Wireshark we use the latter prototype
+ * as 'void *g_malloc (unsigned long n_bytes)'. This was later fixed to the correct prototype
+ * 'void *g_malloc (size_t n_bytes)'. In Wireshark we use the latter prototype
  * throughout the code. We can get away with this even with older versions of GLib by
  * adding a '(void *(*)(size_t))' cast whenever we refer to g_malloc. The only platform
- * supported by Wireshark where this isn't safe (sizeof size_t != sizeof gulong) is Win64.
+ * supported by Wireshark where this isn't safe (sizeof size_t != sizeof unsigned long) is Win64.
  * However, we _always_ bundle the newest version of GLib on this platform so
  * the size_t issue doesn't exists here. Pheew.. */
 static void *(*allocator)(size_t) = (void *(*)(size_t)) g_malloc;
 static void (*deallocator)(void *) = g_free;
-static struct except_stacknode *stack_top;
+static WS_THREAD_LOCAL struct except_stacknode *stack_top;
 
 #define get_top() (stack_top)
 #define set_top(T) (stack_top = (T))
@@ -306,7 +313,7 @@ WS_NORETURN void except_throwd(long group, long code, const char *msg, void *dat
 }
 
 /*
- * XXX - should we use g_strdup_sprintf() here, so we're not limited by
+ * XXX - should we use ws_strdup_printf() here, so we're not limited by
  * XCEPT_BUFFER_SIZE?  We could then just use this to generate formatted
  * messages.
  */
@@ -315,7 +322,7 @@ WS_NORETURN void except_vthrowf(long group, long code, const char *fmt,
 {
     char *buf = (char *)except_alloc(XCEPT_BUFFER_SIZE);
 
-    g_vsnprintf(buf, XCEPT_BUFFER_SIZE, fmt, vl);
+    vsnprintf(buf, XCEPT_BUFFER_SIZE, fmt, vl);
     except_throwd(group, code, buf, buf);
 }
 
@@ -326,6 +333,7 @@ WS_NORETURN void except_throwf(long group, long code, const char *fmt, ...)
     va_start (vl, fmt);
     except_vthrowf(group, code, fmt, vl);
     va_end (vl);
+    ws_assert_not_reached(); /* GCC 12 with ASAN needs this. */
 }
 
 void (*except_unhandled_catcher(void (*new_catcher)(except_t *)))(except_t *)
@@ -392,13 +400,13 @@ void except_free(void *ptr)
 
 static void cleanup(void *arg)
 {
-    ws_debug_printf("cleanup(\"%s\") called\n", (char *) arg);
+    printf("cleanup(\"%s\") called\n", (char *) arg);
 }
 
 static void bottom_level(void)
 {
     char buf[256];
-    ws_debug_printf("throw exception? "); fflush(stdout);
+    printf("throw exception? "); fflush(stdout);
     fgets(buf, sizeof buf, stdin);
 
     if (buf[0] >= 0 && (buf[0] == 'Y' || buf[0] == 'y'))
@@ -433,10 +441,10 @@ int main(int argc, char **argv)
             /* inner catch */
             msg = except_message(ex);
             if (msg == NULL) {
-                ws_debug_printf("caught exception (inner): s=%lu, c=%lu\n",
+                printf("caught exception (inner): s=%lu, c=%lu\n",
                        except_group(ex), except_code(ex));
             } else {
-                ws_debug_printf("caught exception (inner): \"%s\", s=%lu, c=%lu\n",
+                printf("caught exception (inner): \"%s\", s=%lu, c=%lu\n",
                        msg, except_group(ex), except_code(ex));
             }
             except_rethrow(ex);
@@ -446,10 +454,10 @@ int main(int argc, char **argv)
         /* outer catch */
         msg = except_message(ex);
         if (msg == NULL) {
-            ws_debug_printf("caught exception (outer): s=%lu, c=%lu\n",
+            printf("caught exception (outer): s=%lu, c=%lu\n",
                    except_group(ex), except_code(ex));
         } else {
-            ws_debug_printf("caught exception (outer): \"%s\", s=%lu, c=%lu\n",
+            printf("caught exception (outer): \"%s\", s=%lu, c=%lu\n",
                    except_message(ex), except_group(ex), except_code(ex));
         }
     }
@@ -459,7 +467,7 @@ int main(int argc, char **argv)
 }
 
 
-#endif
+#endif /* KAZLIB_TEST_MAIN */
 
 /*
  * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
