@@ -16,6 +16,7 @@
 #include <wsutil/array.h>
 #include <epan/exceptions.h>
 #include <epan/expert.h>
+#include <epan/prefs.h>
 #include <stdio.h>
 #include <inttypes.h>
 #include "wscbor.h"
@@ -60,19 +61,19 @@ typedef struct {
 static void wscbor_read_unsigned(wscbor_head_t *head, tvbuff_t *tvb) {
     switch (head->type_minor) {
         case 0x18:
-            head->rawvalue = tvb_get_guint8(tvb, head->start + head->length);
+            head->rawvalue = tvb_get_uint8(tvb, head->start + head->length);
             head->length += 1;
             break;
         case 0x19:
-            head->rawvalue = tvb_get_guint16(tvb, head->start + head->length, ENC_BIG_ENDIAN);
+            head->rawvalue = tvb_get_uint16(tvb, head->start + head->length, ENC_BIG_ENDIAN);
             head->length += 2;
             break;
         case 0x1A:
-            head->rawvalue = tvb_get_guint32(tvb, head->start + head->length, ENC_BIG_ENDIAN);
+            head->rawvalue = tvb_get_uint32(tvb, head->start + head->length, ENC_BIG_ENDIAN);
             head->length += 4;
             break;
         case 0x1B:
-            head->rawvalue = tvb_get_guint64(tvb, head->start + head->length, ENC_BIG_ENDIAN);
+            head->rawvalue = tvb_get_uint64(tvb, head->start + head->length, ENC_BIG_ENDIAN);
             head->length += 8;
             break;
         default:
@@ -96,7 +97,7 @@ static wscbor_head_t * wscbor_head_read(wmem_allocator_t *alloc, tvbuff_t *tvb,
     wscbor_head_t *head = wmem_new0(alloc, wscbor_head_t);
 
     head->start = *offset;
-    const uint8_t first = tvb_get_guint8(tvb, head->start);
+    const uint8_t first = tvb_get_uint8(tvb, head->start);
     head->length += 1;
 
     // Match libcbor enums
@@ -365,7 +366,12 @@ bool wscbor_is_indefinite_break(const wscbor_chunk_t *chunk) {
  * an indefinite break.
  * @return True if the skipped item was fully valid.
  */
-static bool wscbor_skip_next_item_internal(wmem_allocator_t *alloc, tvbuff_t *tvb, int *offset, bool *is_break) {
+// NOLINTNEXTLINE(misc-no-recursion)
+static bool wscbor_skip_next_item_internal(wmem_allocator_t *alloc, tvbuff_t *tvb, int *offset, bool *is_break, unsigned depth) {
+    if (depth > prefs.gui_max_tree_depth) {
+
+        return false;
+    }
     wscbor_chunk_t *chunk = wscbor_chunk_read(alloc, tvb, offset);
     if (wscbor_has_errors(chunk)) {
         wscbor_chunk_free(chunk);
@@ -379,14 +385,14 @@ static bool wscbor_skip_next_item_internal(wmem_allocator_t *alloc, tvbuff_t *tv
             break;
         case CBOR_TYPE_BYTESTRING:
         case CBOR_TYPE_STRING:
-            // wscbor_read_chunk() sets offset past string value
+            // wscbor_chunk_read() sets offset past string value
             break;
         case CBOR_TYPE_ARRAY: {
             if (chunk->type_minor == 31) {
                 // wait for indefinite break
                 bool was_break = false;
                 do {
-                    if (!wscbor_skip_next_item_internal(alloc, tvb, offset, &was_break)) {
+                    if (!wscbor_skip_next_item_internal(alloc, tvb, offset, &was_break, depth + 1)) {
                         return false;
                     }
                 }
@@ -395,7 +401,7 @@ static bool wscbor_skip_next_item_internal(wmem_allocator_t *alloc, tvbuff_t *tv
             else {
                 const uint64_t count = chunk->head_value;
                 for (uint64_t ix = 0; ix < count; ++ix) {
-                    if (!wscbor_skip_next_item_internal(alloc, tvb, offset, NULL)) {
+                    if (!wscbor_skip_next_item_internal(alloc, tvb, offset, NULL, depth + 1)) {
                         return false;
                     }
                 }
@@ -407,7 +413,7 @@ static bool wscbor_skip_next_item_internal(wmem_allocator_t *alloc, tvbuff_t *tv
                 // wait for indefinite break
                 bool was_break = false;
                 do {
-                    if (!wscbor_skip_next_item_internal(alloc, tvb, offset, &was_break)) {
+                    if (!wscbor_skip_next_item_internal(alloc, tvb, offset, &was_break, depth + 1)) {
                         return false;
                     }
                 }
@@ -416,10 +422,10 @@ static bool wscbor_skip_next_item_internal(wmem_allocator_t *alloc, tvbuff_t *tv
             else {
                 const uint64_t count = chunk->head_value;
                 for (uint64_t ix = 0; ix < count; ++ix) {
-                    if (!wscbor_skip_next_item_internal(alloc, tvb, offset, NULL)) {
+                    if (!wscbor_skip_next_item_internal(alloc, tvb, offset, NULL, depth + 1)) {
                         return false;
                     }
-                    if (!wscbor_skip_next_item_internal(alloc, tvb, offset, NULL)) {
+                    if (!wscbor_skip_next_item_internal(alloc, tvb, offset, NULL, depth + 1)) {
                         return false;
                     }
                 }
@@ -438,7 +444,7 @@ static bool wscbor_skip_next_item_internal(wmem_allocator_t *alloc, tvbuff_t *tv
 }
 
 bool wscbor_skip_next_item(wmem_allocator_t *alloc, tvbuff_t *tvb, int *offset) {
-    return wscbor_skip_next_item_internal(alloc, tvb, offset, NULL);
+    return wscbor_skip_next_item_internal(alloc, tvb, offset, NULL, 0);
 }
 
 bool wscbor_skip_if_errors(wmem_allocator_t *alloc, tvbuff_t *tvb, int *offset, const wscbor_chunk_t *chunk) {
@@ -636,7 +642,7 @@ proto_item * proto_tree_add_cbor_int64(proto_tree *tree, int hfindex, packet_inf
 }
 
 proto_item * proto_tree_add_cbor_bitmask(proto_tree *tree, int hfindex, const int ett, int *const *fields, packet_info *pinfo, tvbuff_t *tvb, const wscbor_chunk_t *chunk, const uint64_t *value) {
-    header_field_info *field = proto_registrar_get_nth(hfindex);
+    const header_field_info *field = proto_registrar_get_nth(hfindex);
     int flagsize = 0;
     switch (field->type) {
         case FT_UINT8:
