@@ -12,11 +12,10 @@
 #ifndef __FILE_H__
 #define __FILE_H__
 
-#include <errno.h>
-
 #include <wiretap/wtap.h>
 #include <epan/epan.h>
 #include <epan/print.h>
+#include <epan/fifo_string_cache.h>
 #include <ui/packet_range.h>
 
 #ifdef __cplusplus
@@ -71,14 +70,16 @@ typedef enum {
     cf_cb_file_save_stopped
 } cf_cbs;
 
-typedef void (*cf_callback_t) (gint event, gpointer data, gpointer user_data);
+typedef void (*cf_callback_t) (int event, void *data, void *user_data);
 
 typedef struct {
     const char    *string;
     size_t         string_len;
     capture_file  *cf;
-    gboolean       frame_matched;
     field_info    *finfo;
+    field_info    *prev_finfo;
+    bool           frame_matched;
+    bool           halt;
 } match_data;
 
 /**
@@ -87,7 +88,7 @@ typedef struct {
  * @param max_records maximum number of records to support.
  */
 extern void
-cf_set_max_records(guint max_records);
+cf_set_max_records(unsigned max_records);
 
 /**
  * Add a capture file event callback.
@@ -101,7 +102,7 @@ cf_set_max_records(guint max_records);
  */
 
 extern void
-cf_callback_add(cf_callback_t func, gpointer user_data);
+cf_callback_add(cf_callback_t func, void *user_data);
 
 /**
  * Remove a capture file event callback.
@@ -111,7 +112,7 @@ cf_callback_add(cf_callback_t func, gpointer user_data);
  */
 
 extern void
-cf_callback_remove(cf_callback_t func, gpointer user_data);
+cf_callback_remove(cf_callback_t func, void *user_data);
 
 /**
  * Open a capture file.
@@ -123,7 +124,7 @@ cf_callback_remove(cf_callback_t func, gpointer user_data);
  * @param err error code
  * @return one of cf_status_t
  */
-cf_status_t cf_open(capture_file *cf, const char *fname, unsigned int type, gboolean is_tempfile, int *err);
+cf_status_t cf_open(capture_file *cf, const char *fname, unsigned int type, bool is_tempfile, int *err);
 
 /**
  * Close a capture file.
@@ -144,39 +145,38 @@ cf_status_t cf_reload(capture_file *cf);
  * Read all packets of a capture file into the internal structures.
  *
  * @param cf the capture file to be read
- * @param from_save reread asked from cf_save_records
+ * @param reloading reread asked for from cf_save_records()
  * @return one of cf_read_status_t
  */
-cf_read_status_t cf_read(capture_file *cf, gboolean from_save);
+cf_read_status_t cf_read(capture_file *cf, bool reloading);
 
 /**
- * Read the metadata and raw data for a record.  It will pop
- * up an alert box if there's an error.
+ * Read the information for a record.  It will pop up an alert box
+ * if there's an error.
  *
  * @param cf the capture file from which to read the record
  * @param fdata the frame_data structure for the record in question
  * @param rec pointer to a wtap_rec structure to contain the
- * record's metadata
- * @param buf a Buffer into which to read the record's raw data
- * @return TRUE if the read succeeded, FALSE if there was an error
+ *           record's information
+ * @return true if the read succeeded, false if there was an error
  */
-gboolean cf_read_record(capture_file *cf, const frame_data *fdata,
-                          wtap_rec *rec, Buffer *buf);
+bool cf_read_record(capture_file *cf, const frame_data *fdata,
+                    wtap_rec *rec);
 
 /** Same as cf_read_record() but does not pop alert box on error */
-gboolean cf_read_record_no_alert(capture_file *cf, const frame_data *fdata,
-                                 wtap_rec *rec, Buffer *buf);
+bool cf_read_record_no_alert(capture_file *cf, const frame_data *fdata,
+                             wtap_rec *rec);
 
 
 /**
- * Read the metadata and raw data for the current record into a
- * capture_file structure's rec and buf for the current record.
+ * Read the information for the current record into a capture_file
+ * structure's rec for the current record.
  * It will pop up an alert box if there's an error.
  *
  * @param cf the capture file from which to read the record
- * @return TRUE if the read succeeded, FALSE if there was an error
+ * @return true if the read succeeded, false if there was an error
  */
-gboolean cf_read_current_record(capture_file *cf);
+bool cf_read_current_record(capture_file *cf);
 
 /**
  * Read packets from the "end" of a capture file.
@@ -184,12 +184,12 @@ gboolean cf_read_current_record(capture_file *cf);
  * @param cf the capture file to be read from
  * @param to_read the number of packets to read
  * @param rec pointer to wtap_rec to use when reading
- * @param buf pointer to Buffer to use when reading
  * @param err the error code, if an error had occurred
  * @return one of cf_read_status_t
  */
 cf_read_status_t cf_continue_tail(capture_file *cf, volatile int to_read,
-                                  wtap_rec *rec, Buffer *buf, int *err);
+                                  wtap_rec *rec, int *err,
+                                  fifo_string_cache_t *frame_dup_cache, GChecksum *frame_cksum);
 
 /**
  * Fake reading packets from the "end" of a capture file.
@@ -203,46 +203,46 @@ void cf_fake_continue_tail(capture_file *cf);
  *
  * @param cf the capture file to be read from
  * @param rec pointer to wtap_rec to use when reading
- * @param buf pointer to Buffer to use when reading
  * @param err the error code, if an error had occurred
  * @return one of cf_read_status_t
  */
 cf_read_status_t cf_finish_tail(capture_file *cf, wtap_rec *rec,
-                                Buffer *buf, int *err);
+                                int *err,
+                                fifo_string_cache_t *frame_dup_cache, GChecksum *frame_cksum);
 
 /**
  * Determine whether this capture file (or a range of it) can be written
  * in any format using Wiretap rather than by copying the raw data.
  *
  * @param cf the capture file to check
- * @return TRUE if it can be written, FALSE if it can't
+ * @return true if it can be written, false if it can't
  */
-gboolean cf_can_write_with_wiretap(capture_file *cf);
+bool cf_can_write_with_wiretap(capture_file *cf);
 
 /**
  * Determine whether this capture file can be saved with a "save" operation;
  * if there's nothing unsaved, it can't.
  *
  * @param cf the capture file to check
- * @return TRUE if it can be saved, FALSE if it can't
+ * @return true if it can be saved, false if it can't
  */
-gboolean cf_can_save(capture_file *cf);
+bool cf_can_save(capture_file *cf);
 
 /**
  * Determine whether this capture file can be saved with a "save as" operation.
  *
  * @param cf the capture file to check
- * @return TRUE if it can be saved, FALSE if it can't
+ * @return true if it can be saved, false if it can't
  */
-gboolean cf_can_save_as(capture_file *cf);
+bool cf_can_save_as(capture_file *cf);
 
 /**
  * Determine whether this capture file has unsaved data.
  *
  * @param cf the capture file to check
- * @return TRUE if it has unsaved data, FALSE if it doesn't
+ * @return true if it has unsaved data, false if it doesn't
  */
-gboolean cf_has_unsaved_data(capture_file *cf);
+bool cf_has_unsaved_data(capture_file *cf);
 
 /**
  * Save all packets in a capture file to a new file, and, if that succeeds,
@@ -255,18 +255,18 @@ gboolean cf_has_unsaved_data(capture_file *cf);
  * @param fname the filename to save to
  * @param save_format the format of the file to save (libpcap, ...)
  * @param compression_type type of compression to use when writing, if any
- * @param discard_comments TRUE if we should discard comments if the save
+ * @param discard_comments true if we should discard comments if the save
  * succeeds (because we saved in a format that doesn't support
  * comments)
- * @param dont_reopen TRUE if it shouldn't reopen and make that file the
+ * @param dont_reopen true if it shouldn't reopen and make that file the
  * current capture file
  * @return one of cf_write_status_t
  */
 cf_write_status_t cf_save_records(capture_file * cf, const char *fname,
-                                  guint save_format,
+                                  unsigned save_format,
                                   wtap_compression_type compression_type,
-                                  gboolean discard_comments,
-                                  gboolean dont_reopen);
+                                  bool discard_comments,
+                                  bool dont_reopen);
 
 /**
  * Export some or all packets from a capture file to a new file.  If there's
@@ -285,7 +285,7 @@ cf_write_status_t cf_save_records(capture_file * cf, const char *fname,
 cf_write_status_t cf_export_specified_packets(capture_file *cf,
                                               const char *fname,
                                               packet_range_t *range,
-                                              guint save_format,
+                                              unsigned save_format,
                                               wtap_compression_type compression_type);
 
 /**
@@ -294,7 +294,7 @@ cf_write_status_t cf_export_specified_packets(capture_file *cf,
  * @param cf the capture file
  * @return the displayable name (must be g_free'd)
  */
-gchar *cf_get_display_name(capture_file *cf);
+char *cf_get_display_name(capture_file *cf);
 
 /**
  * Get a name that can be used to generate a file name from the
@@ -305,7 +305,7 @@ gchar *cf_get_display_name(capture_file *cf);
  * @param cf the capture file
  * @return the base name (must be g_free'd)
  */
-gchar *cf_get_basename(capture_file *cf);
+char *cf_get_basename(capture_file *cf);
 
 /**
  * Set the source of the capture data for temporary files, e.g.
@@ -314,7 +314,7 @@ gchar *cf_get_basename(capture_file *cf);
  * @param cf the capture file
  * @param source the source description. this will be copied internally.
  */
-void cf_set_tempfile_source(capture_file *cf, gchar *source);
+void cf_set_tempfile_source(capture_file *cf, char *source);
 
 /**
  * Get the source of the capture data for temporary files. Guaranteed to
@@ -322,7 +322,7 @@ void cf_set_tempfile_source(capture_file *cf, gchar *source);
  *
  * @param cf the capture file
  */
-const gchar *cf_get_tempfile_source(capture_file *cf);
+const char *cf_get_tempfile_source(capture_file *cf);
 
 /**
  * Get the number of packets in the capture file.
@@ -336,22 +336,22 @@ int cf_get_packet_count(capture_file *cf);
  * Is this capture file a temporary file?
  *
  * @param cf the capture file
- * @return TRUE if it's a temporary file, FALSE otherwise
+ * @return true if it's a temporary file, false otherwise
  */
-gboolean cf_is_tempfile(capture_file *cf);
+bool cf_is_tempfile(capture_file *cf);
 
 /**
  * Set flag, that this file is a tempfile.
  */
-void cf_set_tempfile(capture_file *cf, gboolean is_tempfile);
+void cf_set_tempfile(capture_file *cf, bool is_tempfile);
 
 /**
  * Set flag, if the number of packet drops while capturing are known or not.
  *
  * @param cf the capture file
- * @param drops_known TRUE if the number of packet drops are known, FALSE otherwise
+ * @param drops_known true if the number of packet drops are known, false otherwise
  */
-void cf_set_drops_known(capture_file *cf, gboolean drops_known);
+void cf_set_drops_known(capture_file *cf, bool drops_known);
 
 /**
  * Set the number of packet drops while capturing.
@@ -359,15 +359,15 @@ void cf_set_drops_known(capture_file *cf, gboolean drops_known);
  * @param cf the capture file
  * @param drops the number of packet drops occurred while capturing
  */
-void cf_set_drops(capture_file *cf, guint32 drops);
+void cf_set_drops(capture_file *cf, uint32_t drops);
 
 /**
  * Get flag state, if the number of packet drops while capturing are known or not.
  *
  * @param cf the capture file
- * @return TRUE if the number of packet drops are known, FALSE otherwise
+ * @return true if the number of packet drops are known, false otherwise
  */
-gboolean cf_get_drops_known(capture_file *cf);
+bool cf_get_drops_known(capture_file *cf);
 
 /**
  * Get the number of packet drops while capturing.
@@ -375,7 +375,7 @@ gboolean cf_get_drops_known(capture_file *cf);
  * @param cf the capture file
  * @return the number of packet drops occurred while capturing
  */
-guint32 cf_get_drops(capture_file *cf);
+uint32_t cf_get_drops(capture_file *cf);
 
 /**
  * Set the read filter.
@@ -391,10 +391,10 @@ void cf_set_rfcode(capture_file *cf, dfilter_t *rfcode);
  *
  * @param cf the capture file
  * @param dfilter the display filter
- * @param force TRUE if do in any case, FALSE only if dfilter changed
+ * @param force true if do in any case, false only if dfilter changed
  * @return one of cf_status_t
  */
-cf_status_t cf_filter_packets(capture_file *cf, gchar *dfilter, gboolean force);
+cf_status_t cf_filter_packets(capture_file *cf, char *dfilter, bool force);
 
 /**
  * Scan through all frame data and recalculate the ref time
@@ -407,7 +407,7 @@ void cf_reftime_packets(capture_file *cf);
 /**
  * Return the time it took to load the file (in msec).
  */
-gulong cf_get_computed_elapsed(capture_file *cf);
+unsigned long cf_get_computed_elapsed(capture_file *cf);
 
 /**
  * "Something" has changed, rescan all packets.
@@ -424,13 +424,6 @@ void cf_redissect_packets(capture_file *cf);
  */
 cf_read_status_t cf_retap_packets(capture_file *cf);
 
-/**
- * Adjust timestamp precision if auto is selected.
- *
- * @param cf the capture file
- */
-void cf_timestamp_auto_precision(capture_file *cf);
-
 /* print_range, enum which frames should be printed */
 typedef enum {
     print_range_selected_only,    /* selected frame(s) only (currently only one) */
@@ -442,19 +435,22 @@ typedef enum {
 typedef struct {
     print_stream_t *stream;       /* the stream to which we're printing */
     print_format_e format;        /* plain text or PostScript */
-    gboolean to_file;             /* TRUE if we're printing to a file */
+    bool to_file;             /* true if we're printing to a file */
     char *file;                   /* file output pathname */
     char *cmd;                    /* print command string (not win32) */
     packet_range_t range;
 
-    gboolean print_summary;       /* TRUE if we should print summary line. */
-    gboolean print_col_headings;  /* TRUE if we should print column headings */
+    bool print_summary;       /* true if we should print summary line. */
+    bool print_col_headings;  /* true if we should print column headings */
     print_dissections_e print_dissections;
-    gboolean print_hex;           /* TRUE if we should print hex data;
-                                   * FALSE if we should print only if not dissected. */
-    guint hexdump_options;        /* Hexdump options if print_hex is TRUE. */
-    gboolean print_formfeed;      /* TRUE if a formfeed should be printed before
+    bool print_hex;           /* true if we should print hex data;
+                                   * false if we should print only if not dissected. */
+    unsigned hexdump_options;        /* Hexdump options if print_hex is true. */
+    bool print_formfeed;      /* true if a formfeed should be printed before
                                    * each new packet */
+
+    /* JSON related option */
+    bool no_duplicate_keys;
 } print_args_t;
 
 /**
@@ -462,11 +458,11 @@ typedef struct {
  *
  * @param cf the capture file
  * @param print_args the arguments what and how to print
- * @param show_progress_bar TRUE if a progress bar is to be shown
+ * @param show_progress_bar true if a progress bar is to be shown
  * @return one of cf_print_status_t
  */
 cf_print_status_t cf_print_packets(capture_file *cf, print_args_t *print_args,
-                                   gboolean show_progress_bar);
+                                   bool show_progress_bar);
 
 /**
  * Print (export) the capture file into PDML format.
@@ -519,21 +515,22 @@ cf_print_status_t cf_write_json_packets(capture_file *cf, print_args_t *print_ar
  * @param cf the capture file
  * @param string the string to find
  * @param dir direction in which to search
- * @return TRUE if a packet was found, FALSE otherwise
+ * @param multiple whether to look for the next occurrence of the same string
+ * in the current packet, or to only match once per frame
+ * @return true if a packet was found, false otherwise
  */
-gboolean cf_find_packet_protocol_tree(capture_file *cf, const char *string,
-                                      search_direction dir);
+bool cf_find_packet_protocol_tree(capture_file *cf, const char *string,
+                                      search_direction dir, bool multiple);
 
 /**
- * Find field with a label that contains text string cfile->sfilter.
+ * Find field with a label that contains the text string cfile->sfilter in
+ * a protocol tree.
  *
  * @param cf the capture file
  * @param tree the protocol tree
- * @param mdata the first field (mdata->finfo) that matched the string
- * @return TRUE if a packet was found, FALSE otherwise
+ * @return The first field in the tree that matched the string if found, NULL otherwise
  */
-extern gboolean cf_find_string_protocol_tree(capture_file *cf, proto_tree *tree,
-                                             match_data *mdata);
+extern field_info* cf_find_string_protocol_tree(capture_file *cf, proto_tree *tree);
 
 /**
  * Find packet whose summary line contains a specified text string.
@@ -541,9 +538,9 @@ extern gboolean cf_find_string_protocol_tree(capture_file *cf, proto_tree *tree,
  * @param cf the capture file
  * @param string the string to find
  * @param dir direction in which to search
- * @return TRUE if a packet was found, FALSE otherwise
+ * @return true if a packet was found, false otherwise
  */
-gboolean cf_find_packet_summary_line(capture_file *cf, const char *string,
+bool cf_find_packet_summary_line(capture_file *cf, const char *string,
                                      search_direction dir);
 
 /**
@@ -553,10 +550,13 @@ gboolean cf_find_packet_summary_line(capture_file *cf, const char *string,
  * @param string the string to find
  * @param string_size the size of the string to find
  * @param dir direction in which to search
- * @return TRUE if a packet was found, FALSE otherwise
+ * @param multiple whether to look for the next occurrence of the same string
+ * in the current packet, or to only match once per frame
+ * @return true if a packet was found, false otherwise
  */
-gboolean cf_find_packet_data(capture_file *cf, const guint8 *string,
-                             size_t string_size, search_direction dir);
+bool cf_find_packet_data(capture_file *cf, const uint8_t *string,
+                             size_t string_size, search_direction dir,
+                             bool multiple);
 
 /**
  * Find packet that matches a compiled display filter.
@@ -564,10 +564,11 @@ gboolean cf_find_packet_data(capture_file *cf, const guint8 *string,
  * @param cf the capture file
  * @param sfcode the display filter to match
  * @param dir direction in which to search
- * @return TRUE if a packet was found, FALSE otherwise
+ * @param start_current whether to start searching from the current frame
+ * @return true if a packet was found, false otherwise
  */
-gboolean cf_find_packet_dfilter(capture_file *cf, dfilter_t *sfcode,
-                                search_direction dir);
+bool cf_find_packet_dfilter(capture_file *cf, dfilter_t *sfcode,
+                                search_direction dir, bool start_current);
 
 /**
  * Find packet that matches a display filter given as a text string.
@@ -575,9 +576,9 @@ gboolean cf_find_packet_dfilter(capture_file *cf, dfilter_t *sfcode,
  * @param cf the capture file
  * @param filter the display filter to match
  * @param dir direction in which to search
- * @return TRUE if a packet was found, FALSE otherwise
+ * @return true if a packet was found, false otherwise
  */
-gboolean
+bool
 cf_find_packet_dfilter_string(capture_file *cf, const char *filter,
                               search_direction dir);
 
@@ -586,27 +587,29 @@ cf_find_packet_dfilter_string(capture_file *cf, const char *filter,
  *
  * @param cf the capture file
  * @param dir direction in which to search
- * @return TRUE if a packet was found, FALSE otherwise
+ * @return true if a packet was found, false otherwise
  */
-gboolean cf_find_packet_marked(capture_file *cf, search_direction dir);
+bool cf_find_packet_marked(capture_file *cf, search_direction dir);
 
 /**
  * Find time-reference packet.
  *
  * @param cf the capture file
  * @param dir direction in which to search
- * @return TRUE if a packet was found, FALSE otherwise
+ * @return true if a packet was found, false otherwise
  */
-gboolean cf_find_packet_time_reference(capture_file *cf, search_direction dir);
+bool cf_find_packet_time_reference(capture_file *cf, search_direction dir);
 
 /**
  * GoTo Packet with the given row.
  *
  * @param cf the capture file
  * @param row the row to go to
- * @return TRUE if this row exists, FALSE otherwise
+ * @param exact if true, fail if the row exists and is filtered (not displayed)
+ * if false, go to the nearest displayed packet instead
+ * @return true if this row exists, false otherwise
  */
-gboolean cf_goto_frame(capture_file *cf, guint row);
+bool cf_goto_frame(capture_file *cf, unsigned row, bool exact);
 
 /**
  * Go to frame specified by currently selected protocol tree field.
@@ -614,17 +617,17 @@ gboolean cf_goto_frame(capture_file *cf, guint row);
  * @todo this is ugly and should be improved!
  *
  * @param cf the capture file
- * @return TRUE if this packet exists, FALSE otherwise
+ * @return true if this packet exists, false otherwise
  */
-gboolean cf_goto_framenum(capture_file *cf);
+bool cf_goto_framenum(capture_file *cf);
 
 /**
  * Select the packet in the given row.
  *
  * @param cf the capture file
- * @param row the row to select
+ * @param frame the frame to be selected
  */
-void cf_select_packet(capture_file *cf, int row);
+void cf_select_packet(capture_file *cf, frame_data *frame);
 
 /**
  * Unselect all packets, if any.
@@ -675,13 +678,13 @@ void cf_unignore_frame(capture_file *cf, frame_data *frame);
  * @param in_file_count the number of input files to merge
  * @param in_filenames array of input filenames
  * @param file_type the output filetype
- * @param do_append FALSE to merge chronologically, TRUE simply append
+ * @param do_append false to merge chronologically, true simply append
  * @return one of cf_status_t
  */
 cf_status_t
-cf_merge_files_to_tempfile(gpointer pd_window, const char *temp_dir, char **out_filenamep,
+cf_merge_files_to_tempfile(void *pd_window, const char *temp_dir, char **out_filenamep,
                            int in_file_count, const char *const *in_filenames,
-                           int file_type, gboolean do_append);
+                           int file_type, bool do_append);
 
 /**
  * Update(replace) the comment on a capture from the SHB data block
@@ -690,7 +693,17 @@ cf_merge_files_to_tempfile(gpointer pd_window, const char *temp_dir, char **out_
  * @param cf the capture file
  * @param comment the string replacing the old comment
  */
-void cf_update_section_comment(capture_file *cf, gchar *comment);
+void cf_update_section_comment(capture_file *cf, char *comment);
+
+/**
+ * Update(replace) the comments on a capture from the SHB data block
+ *
+ * @param cf the capture file
+ * @param shb_idx the index of the SHB (0-indexed)
+ * @param comments a NULL-terminated string array of comments. The function
+ * takes ownership of the string array and frees it and the contents.
+ */
+void cf_update_section_comments(capture_file *cf, unsigned shb_idx, char **comments);
 
 /*
  * Get the packet block for a packet (record).
@@ -709,8 +722,12 @@ wtap_block_t cf_get_packet_block(capture_file *cf, const frame_data *fd);
  * @param cf the capture file
  * @param fd the frame_data structure for the frame
  * @param new_block the block replacing the old block
+ *
+ * @return true if the block is modified for the first time. false if
+ * the block was already modified before, in which case the caller is
+ * responsible for updating the comment count.
  */
-gboolean cf_set_modified_block(capture_file *cf, frame_data *fd, const wtap_block_t new_block);
+bool cf_set_modified_block(capture_file *cf, frame_data *fd, const wtap_block_t new_block);
 
 /**
  * What types of comments does this file have?
@@ -718,7 +735,7 @@ gboolean cf_set_modified_block(capture_file *cf, frame_data *fd, const wtap_bloc
  * @param cf the capture file
  * @return bitset of WTAP_COMMENT_ values
  */
-guint32 cf_comment_types(capture_file *cf);
+uint32_t cf_comment_types(capture_file *cf);
 
 /**
  * Add a resolved address to this file's list of resolved addresses.
@@ -726,9 +743,9 @@ guint32 cf_comment_types(capture_file *cf);
  * @param cf the capture file
  * @param addr a string representing an IPv4 or IPv6 address
  * @param name a string containing a name corresponding to that address
- * @return TRUE if it succeeds, FALSE if not
+ * @return true if it succeeds, false if not
  */
-gboolean cf_add_ip_name_from_string(capture_file *cf, const char *addr, const char *name);
+bool cf_add_ip_name_from_string(capture_file *cf, const char *addr, const char *name);
 
 #ifdef __cplusplus
 }
