@@ -139,6 +139,11 @@ def find_links_in_file(filename):
                 # A url must have a period somewhere
                 if '.' not in url:
                     continue
+
+                # Don't fetch this internal link..
+                if url.find('www.wireshark.org/tools/modelines') != -1:
+                    continue
+
                 global links, all_urls
                 links.append(Link(filename, line_number, url))
                 all_urls.add(url)
@@ -217,7 +222,7 @@ args = parser.parse_args()
 
 
 def is_dissector_file(filename):
-    p = re.compile(r'epan/dissectors/packet-.*\.c')
+    p = re.compile(r'.*(packet|file)-.*\.c')
     return p.match(filename)
 
 
@@ -262,7 +267,6 @@ elif args.open:
 elif args.docs:
     # Find links from doc folder(s)
     find_links_in_folder(os.path.join(os.path.dirname(__file__), '..', 'doc'))
-    find_links_in_folder(os.path.join(os.path.dirname(__file__), '..', 'docbook'))
 
 else:
     # Find links from dissector folder.
