@@ -1,5 +1,4 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
+#!/usr/bin/env python3
 
 #
 # Copyright 2020, Martin Kacer <kacer.martin[AT]gmail.com> and contributors
@@ -22,20 +21,15 @@ import random
 import math
 import hashlib
 import re
+import dateutil.parser
 from collections import OrderedDict
 from scapy import all as scapy
 
-try:
-    # Python 2 forward compatibility
-    range = xrange
-except NameError:
-    pass
-
 # Field anonymization class
 class AnonymizedField:
     '''
     The Anonymization field object specifying anonymization
-    :filed arg: field name
+    :field arg: field name
     :type arg: anonymization type [0 masking 0xff, 1 anonymization shake_256]
     :start arg: If specified, the anonymization starts at given byte number
     :end arg: If specified, the anonymization ends at given byte number
@@ -145,8 +139,7 @@ def read_py_function(name):
     file.close()
     return s
 
-py_header = """#!/usr/bin/env python
-# -*- coding: utf-8 -*-
+py_header = """#!/usr/bin/env python3
 
 # File generated by json2pcap.py
 # json2pcap.py created by Martin Kacer, 2020
@@ -159,12 +152,6 @@ import subprocess
 from collections import OrderedDict
 from scapy import all as scapy
 
-try:
-    # Python 2 forward compatibility
-    range = xrange
-except NameError:
-    pass
-
 # *****************************************************
 # *     PACKET PAYLOAD GENERATED FROM INPUT PCAP      *
 # *     Modify this function to edit the packet       *
@@ -207,10 +194,23 @@ def raw_flat_collector(dict):
     if hasattr(dict, 'items'):
         for k, v in dict.items():
             if k.endswith("_raw"):
-                yield k, v
+                # check if the _raw value is nested list
+                if any(isinstance(i, list) for i in v):
+                    for _v in v:
+                        yield k, _v
+                # else
+                else:
+                    yield k, v
             else:
-                for val in raw_flat_collector(v):
-                    yield val
+                # check if the non _raw value is list
+                if type(v) is list:
+                    for _v in v:
+                        for val in raw_flat_collector(_v):
+                            yield val
+                # else
+                else:
+                    for val in raw_flat_collector(v):
+                        yield val
 
 
 # d - input dictionary, parsed from json
@@ -594,7 +594,7 @@ if args.python is False:
                     if 'frame.time_epoch' in packet['_source']['layers']['frame']:
                         frame_time = packet['_source']['layers']['frame']['frame.time_epoch']
                 else:
-                    # add into value list into raw[5] the field name
+                    # add into value list into raw[-1] the field name
                     if isinstance(raw[1], list):
                         raw[1].append(raw[0])
                         _list.append(raw[1])
@@ -614,12 +614,13 @@ if args.python is False:
                 l = raw[2] * 2   # length
                 b = raw[3]       # bitmask
                 t = raw[4]       # type
-                # raw[5]         # field_name (added by script)
+                # raw[5]         # data source
+                # raw[-1]        # field_name (added by script)
                 h_mask = h       # hex for anonymization mask
 
                 # anonymize fields
-                if (raw[5] in anonymize):
-                    [h, h_mask] = anonymize[raw[5]].anonymize_field(h, t, salt)
+                if (raw[-1] in anonymize):
+                    [h, h_mask] = anonymize[raw[-1]].anonymize_field(h, t, salt)
 
                 if (isinstance(p, (list, tuple)) or isinstance(l, (list, tuple))):
                     for r in raw:
@@ -628,18 +629,19 @@ if args.python is False:
                         _l = r[2] * 2   # length
                         _b = r[3]       # bitmask
                         _t = r[4]       # type
-                        # raw[5]        # field_name (added by script)
+                        # raw[5]        # data source
+                        # raw[-1]       # field_name (added by script)
                         _h_mask = _h    # hex for anonymization mask
 
                         # anonymize fields
-                        if (raw[5] in anonymize):
-                            [_h, _h_mask] = anonymize[raw[5]].anonymize_field(_h, _t, salt)
+                        if (raw[-1] in anonymize):
+                            [_h, _h_mask] = anonymize[raw[-1]].anonymize_field(_h, _t, salt)
 
                         # print("Debug: " + str(raw))
                         frame_raw = rewrite_frame(frame_raw, _h, _p, _l, _b, _t, frame_amask)
 
                         # update anonymization mask
-                        if (raw[5] in anonymize):
+                        if (raw[-1] in anonymize):
                             frame_amask = rewrite_frame(frame_amask, _h_mask, _p, _l, _b, _t)
 
                 else:
@@ -647,7 +649,7 @@ if args.python is False:
                     frame_raw = rewrite_frame(frame_raw, h, p, l, b, t, frame_amask)
 
                     # update anonymization mask
-                    if (raw[5] in anonymize):
+                    if (raw[-1] in anonymize):
                         frame_amask = rewrite_frame(frame_amask, h_mask, p, l, b, t)
 
         # for Linux cooked header replace dest MAC and remove two bytes to reconstruct normal frame using text2pcap
@@ -668,7 +670,7 @@ if args.python is False:
 
         new_packet = scapy.Packet(bytearray.fromhex(frame_raw))
         if frame_time:
-            new_packet.time = float(frame_time)
+            new_packet.time = dateutil.parser.parse(frame_time, dayfirst=True).timestamp()
         pcap_out.write(new_packet)
 
 # Generate python payload only for first packet
