@@ -39,7 +39,8 @@ my %dissector_used = ();
 my %ptrtype_mappings = (
 	"unique" => "NDR_POINTER_UNIQUE",
 	"ref" => "NDR_POINTER_REF",
-	"ptr" => "NDR_POINTER_PTR"
+	"ptr" => "NDR_POINTER_PTR",
+	"full" => "NDR_POINTER_PTR"
 );
 
 my %variable_scalars = (
@@ -309,7 +310,8 @@ sub Bitmap($$$$)
 		}
 	}
 
-	if ($element_count > 0) {
+	# Note that if bitmask is full, some compilers would complain about flags &= (~0xffffffff)
+	if ($element_count > 0 && $element_count < 32) {
 		my $total_ev_hex = sprintf("0x%08x", $total_ev);
 		$self->pidl_code("if (flags & (~$total_ev_hex)) {");
 		$self->pidl_code("\tflags &= (~$total_ev_hex);");
@@ -341,6 +343,7 @@ sub ElementLevel($$$$$$$$)
 		} elsif ($l->{LEVEL} eq "EMBEDDED") {
 			$type = "embedded";
 		}
+
 		$self->pidl_code("offset = dissect_ndr_$type\_pointer(tvb, offset, pinfo, tree, di, drep, $myname\_, $ptrtype_mappings{$l->{POINTER_TYPE}}, \"Pointer to ".field2name(StripPrefixes($e->{NAME}, $self->{conformance}->{strip_prefixes})) . " ($e->{TYPE})\",$hf);");
 	} elsif ($l->{TYPE} eq "ARRAY") {
 		if ($l->{IS_INLINE}) {
@@ -648,18 +651,18 @@ sub Function($$$)
 	} elsif ($fn->{RETURN_TYPE} eq "NTSTATUS") {
 		$self->pidl_code("offset = dissect_ntstatus(tvb, offset, pinfo, tree, di, drep, hf\_$ifname\_status, &status);\n");
 		$self->pidl_code("if (status != 0)");
-		$self->pidl_code("\tcol_append_fstr(pinfo->cinfo, COL_INFO, \", Error: %s\", val_to_str_ext(status, &NT_errors_ext, \"Unknown NT status 0x%08x\"));\n");
+		$self->pidl_code("\tcol_append_fstr(pinfo->cinfo, COL_INFO, \", Error: %s\", val_to_str_ext(pinfo->pool, status, &NT_errors_ext, \"Unknown NT status 0x%08x\"));\n");
 		$return_types{$ifname}->{"status"} = ["NTSTATUS", "NT Error"];
 	} elsif ($fn->{RETURN_TYPE} eq "WERROR") {
 		$self->pidl_code("offset = dissect_ndr_uint32(tvb, offset, pinfo, tree, di, drep, hf\_$ifname\_werror, &status);\n");
 		$self->pidl_code("if (status != 0)");
-		$self->pidl_code("\tcol_append_fstr(pinfo->cinfo, COL_INFO, \", Error: %s\", val_to_str_ext(status, &WERR_errors_ext, \"Unknown DOS error 0x%08x\"));\n");
+		$self->pidl_code("\tcol_append_fstr(pinfo->cinfo, COL_INFO, \", Error: %s\", val_to_str_ext(pinfo->pool, status, &WERR_errors_ext, \"Unknown DOS error 0x%08x\"));\n");
 
 		$return_types{$ifname}->{"werror"} = ["WERROR", "Windows Error"];
 	} elsif ($fn->{RETURN_TYPE} eq "HRESULT") {
 		$self->pidl_code("offset = dissect_ndr_uint32(tvb, offset, pinfo, tree, di, drep, hf\_$ifname\_hresult, &status);\n");
 		$self->pidl_code("if (status != 0)");
-		$self->pidl_code("\tcol_append_fstr(pinfo->cinfo, COL_INFO, \", Error: %s\", val_to_str_ext(status, &HRES_errors_ext, \"Unknown HRES error 0x%08x\"));\n");
+		$self->pidl_code("\tcol_append_fstr(pinfo->cinfo, COL_INFO, \", Error: %s\", val_to_str_ext(pinfo->pool, status, &HRES_errors_ext, \"Unknown HRES error 0x%08x\"));\n");
 		$return_types{$ifname}->{"hresult"} = ["HRESULT", "HRES Windows Error"];
 	} elsif (my $type = getType($fn->{RETURN_TYPE})) {
 		if ($type->{DATA}->{TYPE} eq "ENUM") {
@@ -667,7 +670,7 @@ sub Function($$$)
 
 			$self->pidl_code("offset = $return_dissect(tvb, offset, pinfo, tree, di, drep, hf\_$ifname\_$fn->{RETURN_TYPE}_status, &status);");
 			$self->pidl_code("if (status != 0)");
-			$self->pidl_code("\tcol_append_fstr(pinfo->cinfo, COL_INFO, \", Status: %s\", val_to_str(status, $ifname\_$fn->{RETURN_TYPE}\_vals, \"Unknown " . $fn->{RETURN_TYPE} . " error 0x%08x\"));\n");
+			$self->pidl_code("\tcol_append_fstr(pinfo->cinfo, COL_INFO, \", Status: %s\", val_to_str(pinfo->pool, status, $ifname\_$fn->{RETURN_TYPE}\_vals, \"Unknown " . $fn->{RETURN_TYPE} . " error 0x%08x\"));\n");
 			$return_types{$ifname}->{$fn->{RETURN_TYPE}."_status"} = [$fn->{RETURN_TYPE}, $fn->{RETURN_TYPE}];
 		} elsif ($type->{DATA}->{TYPE} eq "SCALAR") {
 			$self->pidl_code("offset = dissect_ndr_$fn->{RETURN_TYPE}(tvb, offset, pinfo, tree, di, drep, hf\_$ifname\_$fn->{RETURN_TYPE}_status, &status);");
@@ -876,8 +879,16 @@ sub Union($$$$)
 	if (defined $switch_type) {
 		$self->pidl_code("offset = $switch_dissect(tvb, offset, pinfo, tree, di, drep, hf_index, &level);");
 
-		if ($e->{ALIGN} > 1) {
-			$self->pidl_code("ALIGN_TO_$e->{ALIGN}_BYTES;");
+		my $alignValue = $e->{ALIGN};
+		if (property_matches($e, "flag", ".*LIBNDR_FLAG_ALIGN.*")) {
+			my $align_flag = $e->{PROPERTIES}->{flag};
+			if ($align_flag =~ m/LIBNDR_FLAG_ALIGN(\d+)/) {
+				$alignValue = $1;
+			}
+		}
+
+		if ($alignValue > 1) {
+			$self->pidl_code("ALIGN_TO_".$alignValue."_BYTES;");
 			$self->pidl_code("");
 		}
 	}
@@ -1182,7 +1193,9 @@ sub Parse($$$$$)
 	$self->{res}->{headers} .= "#include \"config.h\"\n";
 
 	$self->{res}->{headers} .= "#include <string.h>\n";
-	$self->{res}->{headers} .= "#include <epan/packet.h>\n\n";
+	$self->{res}->{headers} .= "#include <wsutil/array.h>\n";
+	$self->{res}->{headers} .= "#include <epan/packet.h>\n";
+	$self->{res}->{headers} .= "#include <epan/tfs.h>\n\n";
 
 	$self->{res}->{headers} .= "#include \"packet-dcerpc.h\"\n";
 	$self->{res}->{headers} .= "#include \"packet-dcerpc-nt.h\"\n";
