@@ -81,18 +81,16 @@ BASIC_LIST="
 	glib2-devel
 	libgcrypt-devel
 	libpcap-devel
+	libxml2-devel
 	pcre2-devel
 	python3
-	zlib-devel
 	"
 
 ADDITIONAL_LIST="
 	krb5-devel
 	libcap-devel
 	libssh-devel
-	libxml2-devel
 	lz4
-	minizip-devel
 	perl
 	perl-Parse-Yapp
 	python3-pytest
@@ -100,6 +98,7 @@ ADDITIONAL_LIST="
 	snappy-devel
 	spandsp-devel
 	systemd-devel
+	xxhash-devel
 	"
 
 # Uncomment to add PNG compression utilities used by compress-pngs:
@@ -170,17 +169,14 @@ add_packages() {
 add_package BASIC_LIST glib2 || add_package BASIC_LIST libglib-2_0-0 ||
 echo "Required package glib2|libglib-2_0-0 is unavailable" >&2
 
-add_package BASIC_LIST lua53-devel || add_package BASIC_LIST lua-devel ||
-echo "Required package lua53-devel|lua-devel is unavailable" >&2
-
-add_package BASIC_LIST lua53 || add_package BASIC_LIST lua ||
-echo "Required package lua53|lua is unavailable" >&2
+add_package BASIC_LIST lua-devel || add_package BASIC_LIST lua54-devel || add_package BASIC_LIST lua53-devel ||
+echo "Required package lua-devel|lua54-devel|lua53-devel is unavailable" >&2
 
 add_package BASIC_LIST libpcap || add_package BASIC_LIST libpcap1 ||
 echo "Required package libpcap|libpcap1 is unavailable" >&2
 
-add_package BASIC_LIST zlib || add_package BASIC_LIST libz1 ||
-echo "Required package zlib|libz1 is unavailable" >&2
+add_package BASIC_LIST zlib-ng-compat-devel || add_package BASIC_LIST zlib-devel ||
+echo "Optional package zlib-ng-compat-devel|zlib-devel is unavailable" >&2
 
 add_package BASIC_LIST c-ares-devel || add_package BASIC_LIST libcares-devel ||
 echo "Required package c-ares-devel|libcares-devel is unavailable" >&2
@@ -239,21 +235,36 @@ fi
 
 if [ $ADD_QT6 -ne 0 ]
 then
-	# Fedora Qt6 packages required from a minimal installation
-	QT6_LIST=(qt6-qtbase-devel
-			qt6-qttools-devel
-			qt6-qt5compat-devel
-			qt6-qtmultimedia-devel
-			libxkbcommon-devel)
+	# See CMakeLists.txt in the root directory for a list of
+	# Qt6 modules required for a minimal installation
+	# Base and Multimedia pull in most of the other required modules
+	# RH/Fedora and SUSE use slightly different pkg names for modules
+	QT6_LIST=(base
+			tools
+			multimedia)
 
-	for pkg in "${QT6_LIST[@]}"
+	for module in "${QT6_LIST[@]}"
 	do
-		add_package BASIC_LIST "$pkg" ||
-		echo "Qt6 dependency $pkg is unavailable" >&2
+		add_package BASIC_LIST "qt6-qt${module}-devel" ||
+		add_package BASIC_LIST "qt6-${module}-devel" ||
+		echo "Required Qt6 Module $module is unavailable" >&2
 	done
 
+	# qt6-linguist: RHEL, Fedora
+	# qt6-linguist-devel: OpenSUSE
+	add_package BASIC_LIST qt6-linguist ||
+	add_package BASIC_LIST qt6-linguist-devel ||
+	echo "Required Qt6 module LinguistTools is unavailable" >&2
+
+	add_package BASIC_LIST qt6-qt5compat-devel ||
+	echo "Required Qt6 module Qt5Compat is unavailable"
+
+	add_package BASIC_LIST libxkbcommon-devel ||
+	echo "Required Qt6 dependency libxkbcommon-devel is unavailable"
+
 	add_package ADDITIONAL_LIST qt6-qtimageformats ||
-	echo "Optional Qt6 Image Formats is unavailable" >&2
+	add_package ADDITIONAL_LIST qt6-imageformats ||
+	echo "Optional Qt6 module Image Formats is unavailable" >&2
 fi
 
 # This in only required on OpenSUSE
@@ -309,7 +320,7 @@ echo "Optional package docbook-style-xsl|docbook-xsl-stylesheets is unavailable"
 add_package ADDITIONAL_LIST brotli-devel || add_packages ADDITIONAL_LIST libbrotli-devel libbrotlidec1 ||
 echo "Optional packages brotli-devel|libbrotli-devel is unavailable" >&2
 
-add_package ADDITIONAL_LIST libnl3-devel || add_package ADDITIONAL_LIST libnl-devel ||
+add_package ADDITIONAL_LIST libnl3-devel ||
 echo "Optional package libnl3-devel|libnl-devel are unavailable" >&2
 
 add_package ADDITIONAL_LIST ilbc-devel ||
@@ -323,8 +334,8 @@ echo "Optional package opus-devel|libopus-devel is unavailable" >&2
 add_package ADDITIONAL_LIST bcg729-devel ||
 echo "Optional package bcg729-devel is unavailable" >&2
 
-add_package ADDITIONAL_LIST zlib-ng-devel ||
-echo "Optional package zlib-ng-devel is unavailable" >&2
+add_package ADDITIONAL_LIST minizip-ng-compat-devel || add_package ADDITIONAL_LIST minizip-devel ||
+echo "Optional package minizip-ng-compat-devel|minizip-devel is unavailable" >&2
 
 # RHEL 8 / CentOS 8 are missing the -devel packages for sbc and libsmi due to
 # RH deciding not to ship all -devel packages.
@@ -342,6 +353,9 @@ echo "Optional package libsmi-devel is unavailable"
 add_package ADDITIONAL_LIST opencore-amr-devel ||
 echo "Optional package opencore-amr-devel is unavailable" >&2
 
+add_package ADDITIONAL_LIST softhsm ||
+echo "Optional package softhsm is unavailable" >&2
+
 ACTUAL_LIST=$BASIC_LIST
 
 # Now arrange for optional support libraries
@@ -356,7 +370,7 @@ then
 fi
 
 # shellcheck disable=SC2086
-$PM $PM_OPT install $ACTUAL_LIST $OPTIONS
+$PM $PM_OPT install $OPTIONS $ACTUAL_LIST
 
 if [ $ADDITIONAL -eq 0 ]
 then
