@@ -1,7 +1,4 @@
 /* cocoa_bridge.mm
- *
- * This code was taken directly from:
- * https://forum.qt.io/topic/82609/remove-native-mac-menu-items-such-as-show-tab-bar
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -17,6 +14,9 @@
 
 void CocoaBridge::cleanOSGeneratedMenuItems()
 {
+    // This code was taken directly from:
+    // https://forum.qt.io/topic/82609/remove-native-mac-menu-items-such-as-show-tab-bar
+
 #ifdef AVAILABLE_MAC_OS_X_VERSION_10_12_AND_LATER
     // Remove (don't allow) the "Show Tab Bar" menu item from the "View" menu, if
     // supported
@@ -34,15 +34,9 @@ void CocoaBridge::cleanOSGeneratedMenuItems()
     [[NSUserDefaults standardUserDefaults] setBool:NO forKey:@"NSDisabledCharacterPaletteMenuItem"];
 }
 
-/*
- * Editor modelines
- *
- * Local Variables:
- * c-basic-offset: 4
- * tab-width: 8
- * indent-tabs-mode: nil
- * End:
- *
- * ex: set shiftwidth=4 tabstop=8 expandtab:
- * :indentSize=4:tabSize=8:noTabs=true:
- */
+void CocoaBridge::showInFinder(char const *file_path)
+{
+    NSURL *url = [NSURL fileURLWithPath:[NSString stringWithUTF8String:file_path]];
+
+    [[NSWorkspace sharedWorkspace] activateFileViewerSelectingURLs:@[url]];
+}
