@@ -12,8 +12,6 @@
 
 #include "config.h"
 
-#include <glib.h>
-
 #include "wireshark_dialog.h"
 #include "cfile.h"
 #include "packet_list.h"
@@ -66,7 +64,7 @@ private:
     QMenu        context_menu_;
 
     static void     tapReset(void *tapinfo_ptr);
-    static tap_packet_status tapPacket(void *tapinfo_ptr, packet_info *pinfo, epan_dissect_t *, const void *data);
+    static tap_packet_status tapPacket(void *tapinfo_ptr, packet_info *pinfo, epan_dissect_t *, const void *data, tap_flags_t flags);
 
 private slots:
     void on_tableTreeWidget_itemActivated(QTreeWidgetItem *item, int);
