@@ -20,6 +20,7 @@
 #include <epan/dissectors/packet-dcerpc.h>
 
 #include <ui/qt/utils/qt_ui_utils.h>
+#include <ui/qt/utils/variant_pointer.h>
 #include <wsutil/file_util.h>
 #include <wsutil/ws_assert.h>
 
@@ -28,22 +29,136 @@
 static const char *DEFAULT_TABLE = "tcp.port";    // Arbitrary
 static const char *DEFAULT_UI_TABLE = "TCP port";    // Arbitrary
 
-DecodeAsItem::DecodeAsItem()
- : tableName_(DEFAULT_TABLE),
+DecodeAsItem::DecodeAsItem(const char* table_name, const void *selector) :
+ tableName_(DEFAULT_TABLE),
  tableUIName_(DEFAULT_UI_TABLE),
  selectorUint_(0),
  selectorString_(""),
  selectorDCERPC_(NULL),
- default_proto_(DECODE_AS_NONE),
- current_proto_(DECODE_AS_NONE),
+ default_dissector_(DECODE_AS_NONE),
+ current_dissector_(DECODE_AS_NONE),
  dissector_handle_(NULL)
 {
+    if (table_name == nullptr)
+        return;
+
+    init(table_name, selector);
+}
+
+DecodeAsItem::DecodeAsItem(const decode_as_t *entry, const void *selector) :
+ tableName_(DEFAULT_TABLE),
+ tableUIName_(DEFAULT_UI_TABLE),
+ selectorUint_(0),
+ selectorString_(""),
+ selectorDCERPC_(NULL),
+ default_dissector_(DECODE_AS_NONE),
+ current_dissector_(DECODE_AS_NONE),
+ dissector_handle_(NULL)
+{
+    if (entry == nullptr)
+        return;
+
+    init(entry->table_name, selector);
 }
 
 DecodeAsItem::~DecodeAsItem()
 {
 }
 
+void DecodeAsItem::init(const char* table_name, const void *selector)
+{
+    tableName_ = table_name;
+    tableUIName_ = get_dissector_table_ui_name(tableName_);
+
+    dissector_handle_t default_handle = NULL;
+    ftenum_t selector_type = get_dissector_table_selector_type(tableName_);
+    if (FT_IS_STRING(selector_type)) {
+        if (selector != NULL) {
+            default_handle = dissector_get_default_string_handle(tableName_, (const char*)selector);
+            selectorString_ = QString((const char*)selector);
+        }
+    } else if (FT_IS_UINT(selector_type)) {
+        if (selector != NULL) {
+            selectorUint_ = GPOINTER_TO_UINT(selector);
+            default_handle = dissector_get_default_uint_handle(tableName_, selectorUint_);
+        }
+    } else if (selector_type == FT_NONE) {
+        // There is no default for an FT_NONE dissector table
+    } else if (selector_type == FT_GUID) {
+        /* Special handling for DCE/RPC dissectors */
+        if (strcmp(tableName_, DCERPC_TABLE_NAME) == 0) {
+            selectorDCERPC_ = (decode_dcerpc_bind_values_t*)(selector);
+        }
+    }
+
+    if (default_handle != NULL) {
+        default_dissector_ = dissector_handle_get_description(default_handle);
+        // When adding a new record, we set the "current" values equal to
+        // the default, so the user can easily reset the value.
+        // The existing value read from the prefs file should already
+        // be added to the table from reading the prefs file.
+        // When reading existing values the current dissector should be
+        // set explicitly to the actual current value.
+        current_dissector_ = default_dissector_;
+        dissector_handle_ = default_handle;
+    }
+}
+
+void DecodeAsItem::setTable(const decode_as_t *entry)
+{
+    if (entry == nullptr)
+        return;
+
+    tableName_ = entry->table_name;
+    tableUIName_ = get_dissector_table_ui_name(entry->table_name);
+
+    /* XXX: Should the selector values be reset (e.g., to 0 and "")
+     * What if someone tries to change the table to the DCERPC table?
+     * That doesn't really work without the DCERPC special handling.
+     */
+
+    updateHandles();
+}
+
+void DecodeAsItem::setSelector(const QString &value)
+{
+    ftenum_t selector_type = get_dissector_table_selector_type(tableName_);
+
+    if (FT_IS_STRING(selector_type)) {
+        selectorString_ = value;
+    } else if (FT_IS_UINT(selector_type)) {
+        selectorUint_ = value.toUInt(Q_NULLPTR, 0);
+    }
+
+    updateHandles();
+}
+
+void DecodeAsItem::setDissectorHandle(dissector_handle_t handle)
+{
+    dissector_handle_ = handle;
+    if (handle == nullptr) {
+        current_dissector_ = DECODE_AS_NONE;
+    } else {
+        current_dissector_ = dissector_handle_get_description(handle);
+    }
+}
+
+void DecodeAsItem::updateHandles()
+{
+    ftenum_t selector_type = get_dissector_table_selector_type(tableName_);
+    dissector_handle_t default_handle = nullptr;
+
+    if (FT_IS_STRING(selector_type)) {
+        default_handle = dissector_get_default_string_handle(tableName_, qUtf8Printable(selectorString_));
+    } else if (FT_IS_UINT(selector_type)) {
+        default_handle = dissector_get_default_uint_handle(tableName_, selectorUint_);
+    }
+    if (default_handle != nullptr) {
+        default_dissector_ = dissector_handle_get_description(default_handle);
+    } else {
+        default_dissector_ = DECODE_AS_NONE;
+    }
+}
 
 DecodeAsModel::DecodeAsModel(QObject *parent, capture_file *cf) :
     QAbstractTableModel(parent),
@@ -74,9 +189,9 @@ Qt::ItemFlags DecodeAsModel::flags(const QModelIndex &index) const
         break;
     case DecodeAsModel::colSelector:
         {
-        ftenum_t selector_type = get_dissector_table_selector_type(item->tableName_);
+        ftenum_t selector_type = get_dissector_table_selector_type(item->tableName());
         if ((selector_type != FT_NONE) &&
-            (item->selectorDCERPC_ == NULL))
+            (item->selectorDCERPC() == NULL))
             flags |= Qt::ItemIsEditable;
         break;
         }
@@ -119,17 +234,17 @@ QVariant DecodeAsModel::data(const QModelIndex &index, int role) const
         switch (index.column())
         {
         case colTable:
-            return item->tableUIName_;
+            return item->tableUIName();
         case colSelector:
         {
-            ftenum_t selector_type = get_dissector_table_selector_type(item->tableName_);
-            if (IS_FT_UINT(selector_type)) {
-                return entryString(item->tableName_, GUINT_TO_POINTER(item->selectorUint_));
-            } else if (IS_FT_STRING(selector_type)) {
-                return entryString(item->tableName_, (gconstpointer)item->selectorString_.toUtf8().constData());
+            ftenum_t selector_type = get_dissector_table_selector_type(item->tableName());
+            if (FT_IS_UINT(selector_type)) {
+                return entryString(item->tableName(), GUINT_TO_POINTER(item->selectorUint()));
+            } else if (FT_IS_STRING(selector_type)) {
+                return entryString(item->tableName(), (const void *)item->selectorString().toUtf8().constData());
             } else if (selector_type == FT_GUID) {
-                if (item->selectorDCERPC_ != NULL) {
-                    return item->selectorDCERPC_->ctx_id;
+                if (item->selectorDCERPC() != NULL) {
+                    return item->selectorDCERPC()->ctx_id;
                 }
             }
 
@@ -137,13 +252,13 @@ QVariant DecodeAsModel::data(const QModelIndex &index, int role) const
         }
         case colType:
         {
-            ftenum_t selector_type = get_dissector_table_selector_type(item->tableName_);
+            ftenum_t selector_type = get_dissector_table_selector_type(item->tableName());
 
-            if (IS_FT_STRING(selector_type)) {
+            if (FT_IS_STRING(selector_type)) {
                 return tr("String");
-            } else if (IS_FT_UINT(selector_type)) {
+            } else if (FT_IS_UINT(selector_type)) {
                 QString type_desc = tr("Integer, base ");
-                switch (get_dissector_table_param(item->tableName_)) {
+                switch (get_dissector_table_param(item->tableName())) {
                 case BASE_OCT:
                     type_desc.append("8");
                     break;
@@ -160,8 +275,8 @@ QVariant DecodeAsModel::data(const QModelIndex &index, int role) const
             } else if (selector_type == FT_NONE) {
                 return tr("<none>");
             } else if (selector_type == FT_GUID) {
-                if (item->selectorDCERPC_ != NULL) {
-                    return QString("ctx_id");
+                if (item->selectorDCERPC() != NULL) {
+                    return QStringLiteral("ctx_id");
                 } else {
                     return tr("GUID");
                 }
@@ -169,9 +284,9 @@ QVariant DecodeAsModel::data(const QModelIndex &index, int role) const
             break;
         }
         case colDefault:
-            return item->default_proto_;
+            return item->defaultDissector();
         case colProtocol:
-            return item->current_proto_;
+            return item->currentDissector();
         }
         return QVariant();
 
@@ -250,30 +365,25 @@ bool DecodeAsModel::setData(const QModelIndex &cur_index, const QVariant &value,
         for (GList *cur = decode_as_list; cur; cur = cur->next) {
             decode_as_t *entry = (decode_as_t *) cur->data;
             if (valueStr.compare(get_dissector_table_ui_name(entry->table_name)) == 0) {
-                item->tableName_ = entry->table_name;
-                item->tableUIName_ = get_dissector_table_ui_name(entry->table_name);
-
+                item->setTable(entry);
                 //all other columns affected
                 emit dataChanged(index(cur_index.row(), colSelector),
                                  index(cur_index.row(), colProtocol));
-
+                break;
             }
         }
         }
         break;
     case DecodeAsModel::colProtocol:
-        item->current_proto_ = value.toString();
+    {
+        dissector_handle_t handle = VariantPointer<dissector_handle>::asPtr(value);
+        item->setDissectorHandle(handle);
         break;
+    }
     case DecodeAsModel::colSelector:
-        {
-        ftenum_t selector_type = get_dissector_table_selector_type(item->tableName_);
-
-        if (IS_FT_STRING(selector_type)) {
-            item->selectorString_ = value.toString();
-        } else if (IS_FT_UINT(selector_type)) {
-            item->selectorUint_ = value.toString().toUInt(Q_NULLPTR, 0);
-        }
-        }
+        item->setSelector(value.toString());
+        emit dataChanged(index(cur_index.row(), colDefault),
+                         index(cur_index.row(), colProtocol));
         break;
     }
 
@@ -288,100 +398,56 @@ bool DecodeAsModel::insertRows(int row, int count, const QModelIndex &/*parent*/
 
     beginInsertRows(QModelIndex(), row, row);
 
-    DecodeAsItem* item = new DecodeAsItem();
-    DecodeAsItem* alternativeItem = NULL;
-    bool lastItemIsOk = false;
+    DecodeAsItem* item = nullptr;
+    const decode_as_t *firstEntry = nullptr;
 
     if (cap_file_ && cap_file_->edt) {
-        //populate the new Decode As item with the last protocol layer
-        //that can support Decode As
-        wmem_list_frame_t * protos = wmem_list_head(cap_file_->edt->pi.layers);
-        gint8 curr_layer_num_saved = cap_file_->edt->pi.curr_layer_num;
-        guint8 curr_layer_num = 1;
+        // Populate the new Decode As item with the last protocol layer
+        // that can support Decode As and has a selector field for that
+        // present in the frame.
+        //
+        // XXX: This treats 0 (for UInts) and empty strings the same as
+        // the fields for the tables not being present at all.
 
-        while (protos != NULL) {
+        wmem_list_frame_t * protos = wmem_list_tail(cap_file_->edt->pi.layers);
+        int8_t curr_layer_num_saved = cap_file_->edt->pi.curr_layer_num;
+        uint8_t curr_layer_num = wmem_list_count(cap_file_->edt->pi.layers);
+
+        while (protos != NULL && item == nullptr) {
             int proto_id = GPOINTER_TO_INT(wmem_list_frame_data(protos));
-            const gchar * proto_name = proto_get_protocol_filter_name(proto_id);
+            const char * proto_name = proto_get_protocol_filter_name(proto_id);
             for (GList *cur = decode_as_list; cur; cur = cur->next) {
                 decode_as_t *entry = (decode_as_t *) cur->data;
                 if (g_strcmp0(proto_name, entry->name) == 0) {
-                    dissector_handle_t dissector = NULL;
+                    if (firstEntry == nullptr) {
+                        firstEntry = entry;
+                    }
                     ftenum_t selector_type = get_dissector_table_selector_type(entry->table_name);
-                    bool itemOk = false;
-
-                    //reset the default and current protocols in case previous layer
-                    //populated it and this layer doesn't have a handle for it
-                    item->default_proto_ =  item->current_proto_ = DECODE_AS_NONE;
-
-                    item->tableName_ = entry->table_name;
-                    item->tableUIName_ = get_dissector_table_ui_name(entry->table_name);
-
-                    //see if there is a default dissector that matches value
-                    if (IS_FT_STRING(selector_type)) {
-
-                        //pick the first value in the packet as the default
-                        cap_file_->edt->pi.curr_layer_num = curr_layer_num;
-                        gpointer selector = entry->values[0].build_values[0](&cap_file_->edt->pi);
-                        if (selector != NULL) {
-                            item->selectorString_ = entryString(item->tableName_, selector);
-                            dissector = dissector_get_default_string_handle(entry->table_name, (const gchar*)selector);
-                        } else {
-                            item->selectorString_ = "";
-                        }
-                        itemOk = !item->selectorString_.isEmpty();
-
-                    } else if (IS_FT_UINT(selector_type)) {
-
-                        //pick the first value in the packet as the default
-                        cap_file_->edt->pi.curr_layer_num = curr_layer_num;
-                        item->selectorUint_ = GPOINTER_TO_UINT(entry->values[0].build_values[0](&cap_file_->edt->pi));
-                        itemOk = item->selectorUint_ != 0;
-
-                        dissector = dissector_get_default_uint_handle(entry->table_name, item->selectorUint_);
-                    } else if (selector_type == FT_NONE) {
-                        // There is no default for an FT_NONE dissector table
-                        dissector = NULL;
-                        itemOk = true;
-                    } else if (selector_type == FT_GUID) {
-                        /* Special handling for DCE/RPC dissectors */
-                        if (strcmp(entry->name, "dcerpc") == 0) {
-                            item->selectorDCERPC_ = (decode_dcerpc_bind_values_t*)entry->values[0].build_values[0](&cap_file_->edt->pi);
-                            itemOk = true;
-                        }
+                    // Pick the first value in the packet for the current
+                    // layer for the table
+                    // XXX: What if the Decode As table supports multiple
+                    // values, but the first possible one is 0/NULL?
+                    cap_file_->edt->pi.curr_layer_num = curr_layer_num;
+                    void *selector = entry->values[0].build_values[0](&cap_file_->edt->pi);
+                    // FT_NONE tables don't need a value
+                    if (selector != NULL || selector_type == FT_NONE) {
+                        item = new DecodeAsItem(entry, selector);
+                        break;
                     }
 
-                    if (itemOk) {
-                        if (!alternativeItem) {
-                            alternativeItem = new DecodeAsItem();
-                        }
-                        *alternativeItem = *item;
-                    }
-                    lastItemIsOk = itemOk;
-
-                    if (dissector != NULL) {
-                        item->default_proto_ = dissector_handle_get_short_name(dissector);
-                        //When adding a new record, "default" should equal "current", so the user can
-                        //explicitly change it
-                        item->current_proto_ = item->default_proto_;
-                    }
                 }
             }
-            protos = wmem_list_frame_next(protos);
-            curr_layer_num++;
+            protos = wmem_list_frame_prev(protos);
+            curr_layer_num--;
         }
 
         cap_file_->edt->pi.curr_layer_num = curr_layer_num_saved;
     }
 
-    // If the last item has an empty selector (e.g. an empty port number),
-    // prefer an entry that has a valid selector.
-    if (alternativeItem) {
-        if (lastItemIsOk) {
-            delete alternativeItem;
-        } else {
-            delete item;
-            item = alternativeItem;
-        }
+    // If we didn't find an entry with a valid selector, create an entry
+    // from the last table with an empty selector, or an empty entry.
+    if (item == nullptr) {
+        item = new DecodeAsItem(firstEntry);
     }
     decode_as_items_ << item;
 
@@ -396,7 +462,8 @@ bool DecodeAsModel::removeRows(int row, int count, const QModelIndex &/*parent*/
         return false;
 
     beginRemoveRows(QModelIndex(), row, row);
-    decode_as_items_.removeAt(row);
+    DecodeAsItem* item = decode_as_items_.takeAt(row);
+    delete item;
     endRemoveRows();
 
     return true;
@@ -423,14 +490,7 @@ bool DecodeAsModel::copyRow(int dst_row, int src_row)
     DecodeAsItem* src = decode_as_items_[src_row];
     DecodeAsItem* dst = decode_as_items_[dst_row];
 
-    dst->tableName_ = src->tableName_;
-    dst->tableUIName_ = src->tableUIName_;
-    dst->selectorUint_ = src->selectorUint_;
-    dst->selectorString_ = src->selectorString_;
-    dst->selectorDCERPC_ = src->selectorDCERPC_;
-    dst->default_proto_ = src->default_proto_;
-    dst->current_proto_ = src->current_proto_;
-    dst->dissector_handle_ = src->dissector_handle_;
+    *dst = *src;
 
     QVector<int> roles;
     roles << Qt::EditRole << Qt::BackgroundRole;
@@ -439,7 +499,7 @@ bool DecodeAsModel::copyRow(int dst_row, int src_row)
     return true;
 }
 
-prefs_set_pref_e DecodeAsModel::readDecodeAsEntry(gchar *key, const gchar *value, void *private_data, gboolean)
+prefs_set_pref_e DecodeAsModel::readDecodeAsEntry(char *key, const char *value, void *private_data, bool)
 {
     DecodeAsModel *model = (DecodeAsModel*)private_data;
     if (model == NULL)
@@ -450,44 +510,35 @@ prefs_set_pref_e DecodeAsModel::readDecodeAsEntry(gchar *key, const gchar *value
     }
 
     /* Parse into table, selector, initial, current */
-    gchar **values = g_strsplit_set(value, ",", 4);
-    DecodeAsItem *item = new DecodeAsItem();
+    char **values = g_strsplit_set(value, ",", 4);
+    DecodeAsItem *item = nullptr;
 
     dissector_table_t dissector_table = find_dissector_table(values[0]);
 
     QString tableName(values[0]);
-    bool tableNameFound = false;
     // Get the table values from the Decode As list because they are persistent
     for (GList *cur = decode_as_list; cur; cur = cur->next) {
         decode_as_t *entry = (decode_as_t *) cur->data;
         if (tableName.compare(entry->table_name) == 0) {
-            item->tableName_ = entry->table_name;
-            item->tableUIName_ = get_dissector_table_ui_name(entry->table_name);
-            tableNameFound = true;
+            item = new DecodeAsItem(entry);
             break;
         }
     }
 
-    if (!tableNameFound || !dissector_table) {
-        delete item;
+    if (item == nullptr) {
         g_strfreev(values);
         return PREFS_SET_SYNTAX_ERR;
     }
 
     QString selector(values[1]);
-    ftenum_t selector_type = get_dissector_table_selector_type(item->tableName_);
+    item->setSelector(selector);
 
-    if (IS_FT_STRING(selector_type)) {
-        item->selectorString_ = selector;
-    } else if (IS_FT_UINT(selector_type)) {
-        item->selectorUint_ = selector.toUInt(Q_NULLPTR, 0);
-    }
-
-    item->default_proto_ = values[2];
-    item->dissector_handle_ = dissector_table_get_dissector_handle(dissector_table, values[3]);
-    if (item->dissector_handle_) {
-        item->current_proto_ = values[3];
-    }
+    /* The value for the default dissector in the decode_as_entries file
+     * has no effect other than perhaps making the config file more
+     * informative when edited manually.
+     * We will actually display and reset to the programmatic default value.
+     */
+    item->setDissectorHandle(dissector_table_get_dissector_handle(dissector_table, values[3]));
 
     model->decode_as_items_ << item;
     g_strfreev(values);
@@ -495,7 +546,7 @@ prefs_set_pref_e DecodeAsModel::readDecodeAsEntry(gchar *key, const gchar *value
     return PREFS_SET_OK;
 }
 
-bool DecodeAsModel::copyFromProfile(QString filename, const gchar **err)
+bool DecodeAsModel::copyFromProfile(QString filename, const char **err)
 {
     FILE *fp = ws_fopen(filename.toUtf8().constData(), "r");
 
@@ -513,7 +564,7 @@ bool DecodeAsModel::copyFromProfile(QString filename, const gchar **err)
     return true;
 }
 
-QString DecodeAsModel::entryString(const gchar *table_name, gconstpointer value)
+QString DecodeAsModel::entryString(const char *table_name, const void *value)
 {
     QString entry_str;
     ftenum_t selector_type = get_dissector_table_selector_type(table_name);
@@ -552,11 +603,11 @@ QString DecodeAsModel::entryString(const gchar *table_name, gconstpointer value)
                 ws_assert_not_reached();
                 break;
             }
-            entry_str = QString("%1").arg(int_to_qstring(num_val, width, 16));
+            entry_str = int_to_qstring(num_val, width, 16);
             break;
 
         case BASE_OCT:
-            entry_str = "0" + QString::number(num_val, 8);
+            entry_str = QStringLiteral("0%1").arg(num_val, 0, 8);
             break;
         }
         break;
@@ -600,97 +651,75 @@ void DecodeAsModel::setDissectorHandle(const QModelIndex &index, dissector_handl
 {
     DecodeAsItem* item = decode_as_items_[index.row()];
     if (item != NULL)
-        item->dissector_handle_ = dissector_handle;
+        item->setDissectorHandle(dissector_handle);
 }
 
-void DecodeAsModel::buildChangedList(const gchar *table_name, ftenum_t, gpointer key, gpointer value, gpointer user_data)
+void DecodeAsModel::buildChangedList(const char *table_name, ftenum_t, void *key, void *value, void *user_data)
 {
     DecodeAsModel *model = (DecodeAsModel*)user_data;
     if (model == NULL)
         return;
 
-    dissector_handle_t default_dh, current_dh;
-    QString default_proto_name(DECODE_AS_NONE), current_proto_name(DECODE_AS_NONE);
-    DecodeAsItem* item = new DecodeAsItem();
-    ftenum_t selector_type = get_dissector_table_selector_type(table_name);
-
-    item->tableName_ = table_name;
-    item->tableUIName_ = get_dissector_table_ui_name(table_name);
-    if (IS_FT_UINT(selector_type)) {
-       item->selectorUint_ = GPOINTER_TO_UINT(key);
-    } else if (IS_FT_STRING(selector_type)) {
-       item->selectorString_ = entryString(table_name, key);
-    }
-
-    default_dh = dtbl_entry_get_initial_handle((dtbl_entry_t *)value);
-    if (default_dh) {
-        default_proto_name = dissector_handle_get_short_name(default_dh);
-    }
-    item->default_proto_ = default_proto_name;
+    dissector_handle_t current_dh;
+    DecodeAsItem* item = new DecodeAsItem(table_name, key);
 
     current_dh = dtbl_entry_get_handle((dtbl_entry_t *)value);
-    if (current_dh) {
-        current_proto_name = QString(dissector_handle_get_short_name(current_dh));
-    }
-    item->current_proto_ = current_proto_name;
-    item->dissector_handle_ = current_dh;
+    item->setDissectorHandle(current_dh);
 
     model->decode_as_items_ << item;
 }
 
-void DecodeAsModel::buildDceRpcChangedList(gpointer data, gpointer user_data)
+void DecodeAsModel::buildDceRpcChangedList(void *data, void *user_data)
 {
     dissector_table_t sub_dissectors;
     guid_key guid_val;
     decode_dcerpc_bind_values_t *binding = (decode_dcerpc_bind_values_t *)data;
-    QString default_proto_name(DECODE_AS_NONE), current_proto_name(DECODE_AS_NONE);
 
     DecodeAsModel *model = (DecodeAsModel*)user_data;
     if (model == NULL)
         return;
 
-    DecodeAsItem* item = new DecodeAsItem();
+    DecodeAsItem* item = new DecodeAsItem(DCERPC_TABLE_NAME, binding);
 
-    item->tableName_ = "dcerpc.uuid";
-    item->tableUIName_ = get_dissector_table_ui_name(item->tableName_);
-
-    item->selectorDCERPC_ = binding;
-
-    sub_dissectors = find_dissector_table(item->tableName_);
+    sub_dissectors = find_dissector_table(DCERPC_TABLE_NAME);
 
     guid_val.ver = binding->ver;
     guid_val.guid = binding->uuid;
-    item->dissector_handle_ = dissector_get_guid_handle(sub_dissectors, &guid_val);
-    if (item->dissector_handle_) {
-        current_proto_name = QString(dissector_handle_get_short_name(item->dissector_handle_));
-    }
-    item->current_proto_ = current_proto_name;
-    item->default_proto_ = default_proto_name;
+    item->setDissectorHandle(dissector_get_guid_handle(sub_dissectors, &guid_val));
 
     model->decode_as_items_ << item;
 }
 
-typedef QPair<const char *, guint32> UintPair;
 typedef QPair<const char *, const char *> CharPtrPair;
 
-void DecodeAsModel::gatherChangedEntries(const gchar *table_name,
-        ftenum_t selector_type, gpointer key, gpointer, gpointer user_data)
+void DecodeAsModel::gatherChangedEntries(const char *table_name,
+        ftenum_t selector_type, void *key, void *value, void *user_data)
 {
     DecodeAsModel *model = qobject_cast<DecodeAsModel*>((DecodeAsModel*)user_data);
     if (model == NULL)
         return;
 
+    dissector_handle_t current = dtbl_entry_get_handle((dtbl_entry_t *)value);
+
     switch (selector_type) {
     case FT_UINT8:
     case FT_UINT16:
     case FT_UINT24:
     case FT_UINT32:
-        model->changed_uint_entries_ << UintPair(table_name, GPOINTER_TO_UINT(key));
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        model->changed_uint_entries_.emplaceBack(table_name, GPOINTER_TO_UINT(key), dissector_handle_get_pref_suffix(current));
+#else
+        model->changed_uint_entries_ << UIntEntry(table_name, GPOINTER_TO_UINT(key), dissector_handle_get_pref_suffix(current));
+#endif
         break;
     case FT_NONE:
         //need to reset dissector table, so this needs to be in a changed list,
         //might as well be the uint one.
-        model->changed_uint_entries_ << UintPair(table_name, 0);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        model->changed_uint_entries_.emplaceBack(table_name, 0, "");
+#else
+        model->changed_uint_entries_ << UIntEntry(table_name, 0, "");
+#endif
         break;
 
     case FT_STRING:
@@ -721,20 +750,20 @@ void DecodeAsModel::applyChanges()
     // If dissector_all_tables_remove_changed existed we could call it
     // instead.
     dissector_all_tables_foreach_changed(gatherChangedEntries, this);
-    foreach (UintPair uint_entry, changed_uint_entries_) {
+    foreach (const auto &uint_entry, changed_uint_entries_) {
         /* Set "Decode As preferences" to default values */
-        sub_dissectors = find_dissector_table(uint_entry.first);
-        handle = dissector_get_uint_handle(sub_dissectors, uint_entry.second);
+        sub_dissectors = find_dissector_table(uint_entry.table);
+        handle = dissector_get_uint_handle(sub_dissectors, uint_entry.key);
         if (handle != NULL) {
             module = prefs_find_module(proto_get_protocol_filter_name(dissector_handle_get_protocol_index(handle)));
-            pref_value = prefs_find_preference(module, uint_entry.first);
+            pref_value = prefs_find_preference(module, uint_entry.pref_name);
             if (pref_value != NULL) {
                 module->prefs_changed_flags |= prefs_get_effect_flags(pref_value);
                 reset_pref(pref_value);
             }
         }
 
-        dissector_reset_uint(uint_entry.first, uint_entry.second);
+        dissector_reset_uint(uint_entry.table, uint_entry.key);
     }
     changed_uint_entries_.clear();
     foreach (CharPtrPair char_ptr_entry, changed_string_entries_) {
@@ -745,17 +774,17 @@ void DecodeAsModel::applyChanges()
     foreach(DecodeAsItem *item, decode_as_items_) {
         decode_as_t       *decode_as_entry;
 
-        if (item->current_proto_.isEmpty()) {
+        if (item->currentDissector().isEmpty()) {
             continue;
         }
 
         for (GList *cur = decode_as_list; cur; cur = cur->next) {
             decode_as_entry = (decode_as_t *) cur->data;
 
-            if (!g_strcmp0(decode_as_entry->table_name, item->tableName_)) {
+            if (!g_strcmp0(decode_as_entry->table_name, item->tableName())) {
 
-                ftenum_t selector_type = get_dissector_table_selector_type(item->tableName_);
-                gconstpointer  selector_value;
+                ftenum_t selector_type = get_dissector_table_selector_type(item->tableName());
+                const void *   selector_value;
                 QByteArray byteArray;
 
                 switch (selector_type) {
@@ -763,23 +792,23 @@ void DecodeAsModel::applyChanges()
                 case FT_UINT16:
                 case FT_UINT24:
                 case FT_UINT32:
-                    selector_value = GUINT_TO_POINTER(item->selectorUint_);
+                    selector_value = GUINT_TO_POINTER(item->selectorUint());
                     break;
                 case FT_STRING:
                 case FT_STRINGZ:
                 case FT_UINT_STRING:
                 case FT_STRINGZPAD:
                 case FT_STRINGZTRUNC:
-                    byteArray = item->selectorString_.toUtf8();
-                    selector_value = (gconstpointer) byteArray.constData();
+                    byteArray = item->selectorString().toUtf8();
+                    selector_value = (const void *) byteArray.constData();
                     break;
                 case FT_NONE:
                     //selector value is ignored, but dissector table needs to happen
                     selector_value = NULL;
                     break;
                 case FT_GUID:
-                    if (item->selectorDCERPC_ != NULL) {
-                        selector_value = (gconstpointer)item->selectorDCERPC_;
+                    if (item->selectorDCERPC() != NULL) {
+                        selector_value = (const void *)item->selectorDCERPC();
                     } else {
                         //TODO: Support normal GUID dissector tables
                         selector_value = NULL;
@@ -789,33 +818,35 @@ void DecodeAsModel::applyChanges()
                     continue;
                 }
 
-                if ((item->current_proto_ == DECODE_AS_NONE) || !item->dissector_handle_) {
+                if ((item->currentDissector() == item->defaultDissector())) {
                     decode_as_entry->reset_value(decode_as_entry->table_name, selector_value);
                     sub_dissectors = find_dissector_table(decode_as_entry->table_name);
 
                     /* For now, only numeric dissector tables can use preferences */
-                    if (IS_FT_UINT(dissector_table_get_type(sub_dissectors))) {
-                        if (item->dissector_handle_ != NULL) {
-                            module = prefs_find_module(proto_get_protocol_filter_name(dissector_handle_get_protocol_index(item->dissector_handle_)));
+                    if (FT_IS_UINT(dissector_table_get_type(sub_dissectors))) {
+                        if (item->dissectorHandle() != NULL) {
+                            module = prefs_find_module(proto_get_protocol_filter_name(dissector_handle_get_protocol_index(item->dissectorHandle())));
                             pref_value = prefs_find_preference(module, decode_as_entry->table_name);
                             if (pref_value != NULL) {
                                 module->prefs_changed_flags |= prefs_get_effect_flags(pref_value);
-                                prefs_remove_decode_as_value(pref_value, item->selectorUint_, TRUE);
+                                prefs_remove_decode_as_value(pref_value, item->selectorUint(), true);
                             }
                         }
                     }
                     break;
                 } else {
-                    decode_as_entry->change_value(decode_as_entry->table_name, selector_value, &item->dissector_handle_, item->current_proto_.toUtf8().constData());
+                    decode_as_entry->change_value(decode_as_entry->table_name, selector_value, item->dissectorHandle(), item->currentDissector().toUtf8().constData());
                     sub_dissectors = find_dissector_table(decode_as_entry->table_name);
 
                     /* For now, only numeric dissector tables can use preferences */
-                    if (IS_FT_UINT(dissector_table_get_type(sub_dissectors))) {
-                        module = prefs_find_module(proto_get_protocol_filter_name(dissector_handle_get_protocol_index(item->dissector_handle_)));
-                        pref_value = prefs_find_preference(module, decode_as_entry->table_name);
-                        if (pref_value != NULL) {
-                            module->prefs_changed_flags |= prefs_get_effect_flags(pref_value);
-                            prefs_add_decode_as_value(pref_value, item->selectorUint_, FALSE);
+                    if (item->dissectorHandle() != NULL) {
+                        if (FT_IS_UINT(dissector_table_get_type(sub_dissectors))) {
+                            module = prefs_find_module(proto_get_protocol_filter_name(dissector_handle_get_protocol_index(item->dissectorHandle())));
+                            pref_value = prefs_find_preference(module, QByteArray(decode_as_entry->table_name).append(dissector_handle_get_pref_suffix(item->dissectorHandle())));
+                            if (pref_value != NULL) {
+                                module->prefs_changed_flags |= prefs_get_effect_flags(pref_value);
+                                prefs_add_decode_as_value(pref_value, item->selectorUint(), false);
+                            }
                         }
                     }
                     break;
