@@ -24,7 +24,6 @@
 #include "ui/recent.h"
 
 #include <epan/color_filters.h>
-#include "frame_tvbuff.h"
 
 #include <ui/qt/utils/color_utils.h>
 #include <ui/qt/utils/qt_ui_utils.h>
@@ -76,8 +75,6 @@ packet_list_recreate_visible_rows(void)
 PacketListModel::PacketListModel(QObject *parent, capture_file *cf) :
     QAbstractItemModel(parent),
     number_to_row_(QVector<int>()),
-    max_row_height_(0),
-    max_line_count_(1),
     idle_dissection_row_(0)
 {
     Q_ASSERT(glbl_plist_model == Q_NULLPTR);
@@ -89,22 +86,6 @@ PacketListModel::PacketListModel(QObject *parent, capture_file *cf) :
     new_visible_rows_.reserve(1000);
     number_to_row_.reserve(reserved_packets_);
 
-    if (qobject_cast<MainWindow *>(mainApp->mainWindow()))
-    {
-            MainWindow *mw = qobject_cast<MainWindow *>(mainApp->mainWindow());
-            QWidget * wtWidget = mw->findChild<WirelessTimeline *>();
-            if (wtWidget && qobject_cast<WirelessTimeline *>(wtWidget))
-            {
-                WirelessTimeline * wt = qobject_cast<WirelessTimeline *>(wtWidget);
-                connect(this, &PacketListModel::bgColorizationProgress,
-                        wt, &WirelessTimeline::bgColorizationProgress);
-            }
-
-    }
-
-    connect(this, &PacketListModel::maxLineCountChanged,
-            this, &PacketListModel::emitItemHeightChanged,
-            Qt::QueuedConnection);
     idle_dissection_timer_ = new QElapsedTimer();
 }
 
@@ -177,8 +158,6 @@ void PacketListModel::clear() {
     new_visible_rows_.resize(0);
     number_to_row_.resize(0);
     endResetModel();
-    max_row_height_ = 0;
-    max_line_count_ = 1;
     idle_dissection_timer_->invalidate();
     idle_dissection_row_ = 0;
 }
@@ -542,15 +521,6 @@ void PacketListModel::deleteAllFrameComments()
     expert_update_comment_count(cap_file_->packet_comment_count);
 }
 
-void PacketListModel::setMaximumRowHeight(int height)
-{
-    max_row_height_ = height;
-    // As the QTreeView uniformRowHeights documentation says,
-    // "The height is obtained from the first item in the view. It is
-    //  updated when the data changes on that item."
-    emit dataChanged(index(0, 0), index(0, columnCount() - 1));
-}
-
 int PacketListModel::sort_column_;
 int PacketListModel::sort_column_is_numeric_;
 int PacketListModel::text_sort_column_;
@@ -571,14 +541,14 @@ void PacketListModel::sort(int column, Qt::SortOrder order)
     if (physical_rows_.count() < 1)
         return;
 
-    sort_column_ = column;
-    text_sort_column_ = PacketListRecord::textColumn(column);
-    sort_order_ = order;
-    sort_cap_file_ = cap_file_;
-
     QString col_title = get_column_title(column);
 
-    if (text_sort_column_ >= 0 && (unsigned)visible_rows_.count() > prefs.gui_packet_list_cached_rows_max) {
+    /* Make sure we're actually going to sort. Note that the header
+     * has no way of knowing that sorting failed, so in these cases
+     * the sort indicator have the value that the user requested
+     * regardless.
+     */
+    if (PacketListRecord::textColumn(column) >= 0 && (unsigned)visible_rows_.count() > prefs.gui_packet_list_cached_rows_max) {
         /* Column not based on frame data but by column text that requires
          * dissection, so to sort in a reasonable amount of time the column
          * text needs to be cached.
@@ -605,15 +575,28 @@ void PacketListModel::sort(int column, Qt::SortOrder order)
      * Similarly, claim the read lock because we don't want the file to
      * change out from under us while sorting, which can segfault. (Previously
      * we ignored user input, but now in order to cancel sorting we don't.)
+     *
+     * This also means we can't sort while still sorting. That would crash
+     * too, because recordLessThan depends on the value of class private
+     * variables, and so we can't change them while a previous sort is using
+     * them. Maybe if we made the comparison function a closure using the
+     * current values.
      */
-    if (sort_cap_file_->read_lock) {
+    if (cap_file_->read_lock) {
         ws_info("Refusing to sort because capture file is being read");
         /* We shouldn't have to tell the user because we're just deferring
-         * the sort until PacketList::captureFileReadFinished
+         * the sort until PacketList::captureFileReadFinished; the case
+         * where we don't sort because we're currently sorting is perhaps
+         * slightly more surprising to the user, but there is a progress bar.
+         * So maybe we should push a status message after all?
          */
         return;
     }
+    sort_cap_file_ = cap_file_;
     sort_cap_file_->read_lock = true;
+    sort_order_ = order;
+    sort_column_ = column;
+    text_sort_column_ = PacketListRecord::textColumn(column);
 
     QString busy_msg;
     if (!col_title.isEmpty()) {
@@ -631,8 +614,7 @@ void PacketListModel::sort(int column, Qt::SortOrder order)
      */
     exp_comps_ = log2(visible_rows_.count()) * visible_rows_.count();
     progress_frame_ = nullptr;
-    if (qobject_cast<MainWindow *>(mainApp->mainWindow())) {
-        MainWindow *mw = qobject_cast<MainWindow *>(mainApp->mainWindow());
+    if (MainWindow *mw = mainApp->mainWindow()) {
         progress_frame_ = mw->findChild<ProgressFrame *>();
         if (progress_frame_) {
             progress_frame_->showProgress(busy_msg, true, false, &stop_flag_, 0);
@@ -700,8 +682,9 @@ bool PacketListModel::isNumericColumn(int column)
     case COL_RSSI:           /**< 22) IEEE 802.11 - received signal strength */
     case COL_TX_RATE:        /**< 23) IEEE 802.11 - TX rate in Mbps */
     case COL_NUMBER:         /**< 32) Packet list item number */
-    case COL_PACKET_LENGTH:  /**< 33) Packet length in bytes */
-    case COL_UNRES_SRC_PORT: /**< 41) Unresolved source port */
+    case COL_NUMBER_DIS:     /**< 33) Packet list item number */
+    case COL_PACKET_LENGTH:  /**< 34) Packet length in bytes */
+    case COL_UNRES_SRC_PORT: /**< 42) Unresolved source port */
         return true;
 
     /*
@@ -710,8 +693,8 @@ bool PacketListModel::isNumericColumn(int column)
      * */
     case COL_RES_DST_PORT:   /**< 10) Resolved dest port */
     case COL_DEF_DST_PORT:   /**< 12) Destination port */
-    case COL_DEF_SRC_PORT:   /**< 37) Source port */
-    case COL_RES_SRC_PORT:   /**< 40) Resolved source port */
+    case COL_DEF_SRC_PORT:   /**< 38) Source port */
+    case COL_RES_SRC_PORT:   /**< 41) Resolved source port */
         return true;
 
     case COL_CUSTOM:
@@ -727,11 +710,10 @@ bool PacketListModel::isNumericColumn(int column)
     for (unsigned i = 0; i < num_fields; i++) {
         col_custom = (col_custom_t *) g_slist_nth_data(sort_cap_file_->cinfo.columns[column].col_custom_fields_ids, i);
         if (col_custom->field_id == 0) {
-            /* XXX - We need some way to check the compiled dfilter's expected
-             * return type. Best would be to use the actual field values return
-             * and sort on those (we could skip expensive string conversions
-             * in the numeric case, see below)
-             */
+            ftenum_t type = dfilter_get_return_type(col_custom->dfilter);
+            if (FT_IS_INTEGER(type) || FT_IS_FLOATING(type) || type == FT_BOOLEAN || type == FT_RELATIVE_TIME) {
+                return true;
+            }
             return false;
         }
         header_field_info *hfi = proto_registrar_get_nth(col_custom->field_id);
@@ -841,20 +823,6 @@ double PacketListModel::parseNumericColumn(const QString &val, bool *ok)
     return num;
 }
 
-// ::data is const so we have to make changes here.
-void PacketListModel::emitItemHeightChanged(const QModelIndex &ih_index)
-{
-    if (!ih_index.isValid()) return;
-
-    PacketListRecord *record = static_cast<PacketListRecord*>(ih_index.internalPointer());
-    if (!record) return;
-
-    if (record->lineCount() > max_line_count_) {
-        max_line_count_ = record->lineCount();
-        emit itemHeightChanged(ih_index);
-    }
-}
-
 int PacketListModel::rowCount(const QModelIndex &) const
 {
     return static_cast<int>(visible_rows_.count());
@@ -922,26 +890,7 @@ QVariant PacketListModel::data(const QModelIndex &d_index, int role) const
         return ColorUtils::fromColorT(color);
     case Qt::DisplayRole:
     {
-        int column = d_index.column();
-        QString column_string = record->columnString(cap_file_, column, true);
-        // We don't know an item's sizeHint until we fetch its text here.
-        // Assume each line count is 1. If the line count changes, emit
-        // itemHeightChanged which triggers another redraw (including a
-        // fetch of SizeHintRole and DisplayRole) in the next event loop.
-        if (column == 0 && record->lineCountChanged() && record->lineCount() > max_line_count_) {
-            emit maxLineCountChanged(d_index);
-        }
-        return column_string;
-    }
-    case Qt::SizeHintRole:
-    {
-        // If this is the first row and column, return the maximum row height...
-        if (d_index.row() < 1 && d_index.column() < 1 && max_row_height_ > 0) {
-            QSize size = QSize(-1, max_row_height_);
-            return size;
-        }
-        // ...otherwise punt so that the item delegate can correctly calculate the item width.
-        return QVariant();
+        return record->columnString(cap_file_, d_index.column(), true);
     }
     default:
         return QVariant();
@@ -959,8 +908,10 @@ QVariant PacketListModel::headerData(int section, Qt::Orientation orientation,
             return QVariant::fromValue(QString(get_column_title(section)));
         case Qt::ToolTipRole:
             return QVariant::fromValue(gchar_free_to_qstring(get_column_tooltip(section)));
-        case PacketListModel::HEADER_CAN_RESOLVE:
-            return (bool)resolve_column(section, cap_file_);
+        case PacketListModel::HEADER_CAN_DISPLAY_STRINGS:
+            return (bool)display_column_strings(section, cap_file_);
+        case PacketListModel::HEADER_CAN_DISPLAY_DETAILS:
+            return (bool)display_column_details(section, cap_file_);
         default:
             break;
         }
@@ -1003,6 +954,12 @@ void PacketListModel::dissectIdle(bool reset)
 
     idle_dissection_timer_->restart();
 
+    if (!cap_file_ || cap_file_->read_lock) {
+        // File is in use (at worst, being rescanned). Try again later.
+        QTimer::singleShot(idle_dissection_interval_, this, [=]() { dissectIdle(); });
+        return;
+    }
+
     int first = idle_dissection_row_;
     while (idle_dissection_timer_->elapsed() < idle_dissection_interval_
            && idle_dissection_row_ < physical_rows_.count()) {
