@@ -7,6 +7,8 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
+#include "config.h"
+
 #include <epan/epan_dissect.h>
 #include "epan/epan.h"
 #include "epan/column.h"
@@ -18,8 +20,6 @@
 #include "file.h"
 #include <ui/qt/capture_file.h>
 
-#include "frame_tvbuff.h"
-
 #include <stdint.h>
 
 #include <ui/qt/utils/frame_information.h>
@@ -30,8 +30,7 @@ FrameInformation::FrameInformation(CaptureFile * capfile, frame_data * fi, QObje
  cap_file_(capfile),
  edt_(Q_NULLPTR)
 {
-    wtap_rec_init(&rec_);
-    ws_buffer_init(&buf_, 1514);
+    wtap_rec_init(&rec_, 1514);
     loadFrameTree();
 }
 
@@ -40,19 +39,18 @@ void FrameInformation::loadFrameTree()
     if (! fi_ || ! cap_file_ || !cap_file_->capFile())
         return;
 
-    if (!cf_read_record(cap_file_->capFile(), fi_, &rec_, &buf_))
+    if (!cf_read_record(cap_file_->capFile(), fi_, &rec_))
         return;
 
     edt_ = g_new0(epan_dissect_t, 1);
 
     /* proto tree, visible. We need a proto tree if there's custom columns */
-    epan_dissect_init(edt_, cap_file_->capFile()->epan, TRUE, TRUE);
+    epan_dissect_init(edt_, cap_file_->capFile()->epan, true, true);
     col_custom_prime_edt(edt_, &(cap_file_->capFile()->cinfo));
 
     epan_dissect_run(edt_, cap_file_->capFile()->cd_t, &rec_,
-                     frame_tvbuff_new_buffer(&cap_file_->capFile()->provider, fi_, &buf_),
                      fi_, &(cap_file_->capFile()->cinfo));
-    epan_dissect_fill_in_columns(edt_, TRUE, TRUE);
+    epan_dissect_fill_in_columns(edt_, true, true);
 }
 
 FrameInformation::~FrameInformation()
@@ -62,7 +60,6 @@ FrameInformation::~FrameInformation()
         g_free(edt_);
     }
     wtap_rec_cleanup(&rec_);
-    ws_buffer_free(&buf_);
 }
 
 bool FrameInformation::isValid()
