@@ -17,22 +17,21 @@
 #include <wiretap/wtap_opttypes.h>
 #include <wsutil/os_version_info.h>
 #include <wsutil/report_message.h>
-
-#include "ui/version_info.h"
+#include "wsutil/version_info.h"
 
 #include "tap_export_pdu.h"
 
 /* Main entry point to the tap */
 static tap_packet_status
-export_pdu_packet(void *tapdata, packet_info *pinfo, epan_dissect_t *edt, const void *data)
+export_pdu_packet(void *tapdata, packet_info *pinfo, epan_dissect_t *edt, const void *data, tap_flags_t flags _U_)
 {
     const exp_pdu_data_t *exp_pdu_data = (const exp_pdu_data_t *)data;
     exp_pdu_t  *exp_pdu_tap_data = (exp_pdu_t *)tapdata;
     wtap_rec rec;
     int err;
-    gchar *err_info;
+    char *err_info;
     int buffer_len;
-    guint8 *packet_buf;
+    uint8_t *packet_buf;
     tap_packet_status status = TAP_PACKET_DONT_REDRAW; /* no GUI, nothing to redraw */
 
     /*
@@ -40,9 +39,9 @@ export_pdu_packet(void *tapdata, packet_info *pinfo, epan_dissect_t *edt, const
      */
     exp_pdu_tap_data->framenum++;
 
-    memset(&rec, 0, sizeof rec);
     buffer_len = exp_pdu_data->tvb_captured_length + exp_pdu_data->tlv_buffer_len;
-    packet_buf = (guint8 *)g_malloc(buffer_len);
+    wtap_rec_init(&rec, buffer_len);
+    packet_buf = ws_buffer_start_ptr(&rec.data);
 
     if(exp_pdu_data->tlv_buffer_len > 0){
         memcpy(packet_buf, exp_pdu_data->tlv_buffer, exp_pdu_data->tlv_buffer_len);
@@ -50,50 +49,48 @@ export_pdu_packet(void *tapdata, packet_info *pinfo, epan_dissect_t *edt, const
     if(exp_pdu_data->tvb_captured_length > 0){
         tvb_memcpy(exp_pdu_data->pdu_tvb, packet_buf+exp_pdu_data->tlv_buffer_len, 0, exp_pdu_data->tvb_captured_length);
     }
-    rec.rec_type                           = REC_TYPE_PACKET;
+    wtap_setup_packet_rec(&rec, exp_pdu_tap_data->pkt_encap);
     rec.presence_flags                     = WTAP_HAS_CAP_LEN|WTAP_HAS_INTERFACE_ID|WTAP_HAS_TS;
     rec.ts.secs                            = pinfo->abs_ts.secs;
     rec.ts.nsecs                           = pinfo->abs_ts.nsecs;
     rec.rec_header.packet_header.caplen    = buffer_len;
     rec.rec_header.packet_header.len       = exp_pdu_data->tvb_reported_length + exp_pdu_data->tlv_buffer_len;
 
-    rec.rec_header.packet_header.pkt_encap = exp_pdu_tap_data->pkt_encap;
-
     /* rec.opt_block is not modified by wtap_dump, but if for some reason the
      * epan_get_modified_block() or pinfo->rec->block are invalidated,
      * copying it here does not hurt. (Can invalidation really happen?) */
     if (pinfo->fd->has_modified_block) {
         rec.block = epan_get_modified_block(edt->session, pinfo->fd);
-        rec.block_was_modified = TRUE;
+        rec.block_was_modified = true;
     } else {
         rec.block = pinfo->rec->block;
     }
 
     /* XXX: should the rec.rec_header.packet_header.pseudo_header be set to the pinfo's pseudo-header? */
-    if (!wtap_dump(exp_pdu_tap_data->wdh, &rec, packet_buf, &err, &err_info)) {
+    if (!wtap_dump(exp_pdu_tap_data->wdh, &rec, &err, &err_info)) {
         report_cfile_write_failure(NULL, exp_pdu_tap_data->pathname,
                                    err, err_info, exp_pdu_tap_data->framenum,
                                    wtap_dump_file_type_subtype(exp_pdu_tap_data->wdh));
         status = TAP_PACKET_FAILED;
     }
 
-    g_free(packet_buf);
+    wtap_rec_cleanup(&rec);
 
     return status;
 }
 
-gboolean
+bool
 exp_pdu_open(exp_pdu_t *exp_pdu_tap_data, char *pathname,
              int file_type_subtype, int fd, const char *comment,
-             int *err, gchar **err_info)
+             int *err, char **err_info)
 {
     /* pcapng defs */
     wtap_block_t                 shb_hdr;
     wtap_block_t                 int_data;
     wtapng_if_descr_mandatory_t *int_data_mand;
     GString                     *os_info_str;
-    gsize                        opt_len;
-    gchar                       *opt_str;
+    size_t                       opt_len;
+    char                        *opt_str;
 
     /*
      * If the file format supports a section block, and the section
@@ -129,7 +126,7 @@ exp_pdu_open(exp_pdu_t *exp_pdu_tap_data, char *pathname,
         wtap_block_add_string_option_format(shb_hdr, OPT_SHB_USERAPPL, "%s",
                                             get_appname_and_version());
 
-        exp_pdu_tap_data->shb_hdrs = g_array_new(FALSE, FALSE, sizeof(wtap_block_t));
+        exp_pdu_tap_data->shb_hdrs = g_array_new(false, false, sizeof(wtap_block_t));
         g_array_append_val(exp_pdu_tap_data->shb_hdrs, shb_hdr);
     } else {
         exp_pdu_tap_data->shb_hdrs = NULL;
@@ -142,7 +139,7 @@ exp_pdu_open(exp_pdu_t *exp_pdu_tap_data, char *pathname,
     if (wtap_file_type_subtype_supports_block(file_type_subtype,
                                               WTAP_BLOCK_IF_ID_AND_INFO) != BLOCK_NOT_SUPPORTED) {
         exp_pdu_tap_data->idb_inf = g_new(wtapng_iface_descriptions_t,1);
-        exp_pdu_tap_data->idb_inf->interface_data = g_array_new(FALSE, FALSE, sizeof(wtap_block_t));
+        exp_pdu_tap_data->idb_inf->interface_data = g_array_new(false, false, sizeof(wtap_block_t));
 
         /* create the fake interface data */
         int_data = wtap_block_create(WTAP_BLOCK_IF_ID_AND_INFO);
@@ -173,17 +170,17 @@ exp_pdu_open(exp_pdu_t *exp_pdu_tap_data, char *pathname,
                 WTAP_UNCOMPRESSED, &params, err, err_info);
     }
     if (exp_pdu_tap_data->wdh == NULL)
-        return FALSE;
+        return false;
 
     exp_pdu_tap_data->pathname = pathname;
     exp_pdu_tap_data->framenum = 0; /* No frames written yet */
-    return TRUE;
+    return true;
 }
 
-gboolean
-exp_pdu_close(exp_pdu_t *exp_pdu_tap_data, int *err, gchar **err_info)
+bool
+exp_pdu_close(exp_pdu_t *exp_pdu_tap_data, int *err, char **err_info)
 {
-    gboolean status;
+    bool status;
 
     status = wtap_dump_close(exp_pdu_tap_data->wdh, NULL, err, err_info);
 
@@ -200,6 +197,20 @@ exp_pdu_pre_open(const char *tap_name, const char *filter, exp_pdu_t *exp_pdu_ta
 {
     GString        *error_string;
 
+    /* Make sure tap is suitable for exported PDUs */
+    bool found = false;
+    for (GSList *export_pdu_tap_name_list = get_export_pdu_tap_list();
+         export_pdu_tap_name_list != NULL;
+         export_pdu_tap_name_list = g_slist_next(export_pdu_tap_name_list)) {
+        if (strcmp((const char*)(export_pdu_tap_name_list->data), tap_name) == 0) {
+            found = true;
+            break;
+        }
+    }
+    if (!found) {
+        return g_strdup("unsuitable for PDU export");
+    }
+
     /* Register this tap listener now */
     error_string = register_tap_listener(tap_name,             /* The name of the tap we want to listen to */
                                          exp_pdu_tap_data,     /* instance identifier/pointer to a struct holding
