@@ -1,4 +1,5 @@
-/**-*-C-*-**********************************************************************
+/** @file
+ *
  * text_import_scanner.h
  * Scanner for text import
  * November 2010, Jaap Keuter <jaap.keuter@xs4all.nl>
@@ -22,6 +23,7 @@ extern "C" {
 
 typedef enum {
     T_BYTE = 1,
+    T_BYTES,
     T_OFFSET,
     T_DIRECTIVE,
     T_TEXT,
@@ -29,12 +31,17 @@ typedef enum {
     T_EOF
 } token_t;
 
+typedef enum {
+    IMPORT_SUCCESS,
+    IMPORT_FAILURE,
+    IMPORT_INIT_FAILED
+} import_status_t;
 
-void parse_token(token_t token, char *str);
+import_status_t parse_token(token_t token, char *str);
 
 extern FILE *text_importin;
 
-int text_import_scan(FILE *input_file);
+import_status_t text_import_scan(FILE *input_file);
 
 #ifdef __cplusplus
 }
