@@ -1,4 +1,4 @@
-/* cosine.h
+/** @file
  *
  * CoSine IPNOS L2 debug output parsing
  * Copyright (c) 2002 by Motonori Shindo <motonori@shin.do>
@@ -12,10 +12,9 @@
 
 #ifndef __W_COSINE_H__
 #define __W_COSINE_H__
-#include <glib.h>
-#include "wtap.h"
-#include "ws_symbol_export.h"
 
-wtap_open_return_val cosine_open(wtap *wth, int *err, gchar **err_info);
+#include "wtap.h"
+
+wtap_open_return_val cosine_open(wtap *wth, int *err, char **err_info);
 
 #endif
