@@ -11,9 +11,8 @@
 #ifndef __W_MPEG_H__
 #define __W_MPEG_H__
 
-#include <glib.h>
 #include "wtap.h"
 
-wtap_open_return_val mpeg_open(wtap *wth, int *err, gchar **err_info);
+wtap_open_return_val mpeg_open(wtap *wth, int *err, char **err_info);
 
 #endif
